@@ -98,7 +98,7 @@ static PilCdb *cfgDB = NULL;
  * replaces a, possibly present, trailing slash by a '\0'.
  */
 
-inline static char *getpath(const char *env)
+ static char *getpath(const char *env)
 {
 
   register char *path = getenv(env);
@@ -130,7 +130,7 @@ inline static char *getpath(const char *env)
  * @b pil_free().
  */
 
-inline static char *rcfilepath(const char *fmt, ...)
+ static char *rcfilepath(const char *fmt, ...)
 {
 
   size_t sz;
@@ -178,7 +178,7 @@ inline static char *rcfilepath(const char *fmt, ...)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetRootDir(const char *instrument)
+ static char *pilDfsGetRootDir(const char *instrument)
 {
 
   register char *s;
@@ -232,7 +232,7 @@ inline static char *pilDfsGetRootDir(const char *instrument)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetHomeDir(void)
+ static char *pilDfsGetHomeDir(void)
 {
 
   register char *path;
@@ -272,7 +272,7 @@ inline static char *pilDfsGetHomeDir(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetLogDir(void)
+ static char *pilDfsGetLogDir(void)
 {
 
   return getpath(DFS_LOGDIR);
@@ -297,7 +297,7 @@ inline static char *pilDfsGetLogDir(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetProductDir(void)
+ static char *pilDfsGetProductDir(void)
 {
 
   return getpath(DFS_PRODIR);
@@ -322,7 +322,7 @@ inline static char *pilDfsGetProductDir(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetRbDir(void)
+ static char *pilDfsGetRbDir(void)
 {
 
   return getpath(DFS_RBDIR);
@@ -348,7 +348,7 @@ inline static char *pilDfsGetRbDir(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetExportDir(void)
+ static char *pilDfsGetExportDir(void)
 {
 
   return getpath(DFS_EXPORTDIR);
@@ -374,7 +374,7 @@ inline static char *pilDfsGetExportDir(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetExportFlag(void)
+ static char *pilDfsGetExportFlag(void)
 {
 
   char *value, *flag;
@@ -420,7 +420,7 @@ inline static char *pilDfsGetExportFlag(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetOverwriteFlag(void)
+ static char *pilDfsGetOverwriteFlag(void)
 {
 
   char *value, *flag;
@@ -463,7 +463,7 @@ inline static char *pilDfsGetOverwriteFlag(void)
  * @b pil_free().
  */
 
-inline static char *pilDfsGetDisplay(void)
+ static char *pilDfsGetDisplay(void)
 {
 
   register char *value = getenv(PIL_DISPLAY);
@@ -513,7 +513,7 @@ inline static char *pilDfsGetDisplay(void)
  *   @li EnableGraphics=false
  */
 
-inline static int pilDfsInitDB(void)
+ static int pilDfsInitDB(void)
 {
 
 
@@ -603,7 +603,7 @@ inline static int pilDfsInitDB(void)
  * @em agent returns @c NULL the database entry is left untouched.
  */
 
-inline static int pilDfsUpdateFromEnv(char *(*agent)(void), const char *group,
+ static int pilDfsUpdateFromEnv(char *(*agent)(void), const char *group,
 				      const char *name)
 {
 
