@@ -95,7 +95,7 @@ struct _PIL_FITS_FILE_ {
  * returns zero.
  */
 
-inline static int
+ static int
 pilFitsKeyType(PilFitsFile *fitsFile, const char *keyName)
 {
 
