@@ -115,7 +115,7 @@ struct _PIL_PAF_ {
  * Compute record type size in bytes.
  */
 
-inline static size_t
+ static size_t
 _pilPAFValueSize(PilPAFType type, const void *value)
 {
     size_t sz;
@@ -151,7 +151,7 @@ _pilPAFValueSize(PilPAFType type, const void *value)
  * Comparison function for looking up records by their name.
  */
 
-inline static int
+ static int
 _pilPAFRecordCompare(const void *record, const void *name)
 {
 
@@ -169,7 +169,7 @@ _pilPAFRecordCompare(const void *record, const void *name)
  * Destroy a PAF record
  */
 
-inline static void
+ static void
 _pilPAFRecordDestroy(PilPAFRecord *record)
 {
 
@@ -195,7 +195,7 @@ _pilPAFRecordDestroy(PilPAFRecord *record)
  * Create a new PAF record
  */
 
-inline static PilPAFRecord *
+ static PilPAFRecord *
 _pilPAFRecordCreate(const char *name, PilPAFType type, const void *value,
                     const char *comment)
 {
@@ -234,7 +234,7 @@ _pilPAFRecordCreate(const char *name, PilPAFType type, const void *value,
  * Set name, value and comment of a PAF record
  */
 
-inline static void
+ static void
 _pilPAFRecordSet(PilPAFRecord *record, const char *name, PilPAFType type,
                  const void *value, const char *comment)
 {
@@ -277,7 +277,7 @@ _pilPAFRecordSet(PilPAFRecord *record, const char *name, PilPAFType type,
  * into the PAF header or record list at the position given by key
  */
 
-inline static int
+ static int
 _pilPAFInsert(PilList *list, const char *key, const char *name,
               PilPAFType type, const void *value, const char *comment)
 {
@@ -310,7 +310,7 @@ _pilPAFInsert(PilList *list, const char *key, const char *name,
  * into the PAF header or record list after the position given by key
  */
 
-inline static int
+ static int
 _pilPAFInsertAfter(PilList *list, const char *key, const char *name,
                    PilPAFType type, const void *value, const char *comment)
 {
@@ -343,7 +343,7 @@ _pilPAFInsertAfter(PilList *list, const char *key, const char *name,
  * the PAF header or record list.
  */
 
-inline static int
+ static int
 _pilPAFPrepend(PilList *list, const char *name, PilPAFType type,
                const void *value, const char *comment)
 {
@@ -372,7 +372,7 @@ _pilPAFPrepend(PilList *list, const char *name, PilPAFType type,
  * the PAF header or record list.
  */
 
-inline static int
+ static int
 _pilPAFAppend(PilList *list, const char *name, PilPAFType type,
               const void *value, const char *comment)
 {
@@ -400,7 +400,7 @@ _pilPAFAppend(PilList *list, const char *name, PilPAFType type,
  * Create a new PAF header.
  */
 
-inline static PilList *
+ static PilList *
 _pilPAFHeaderCreate(const char *name, const char *type, const char *id,
                     const char *desc)
 {
@@ -452,7 +452,7 @@ _pilPAFHeaderCreate(const char *name, const char *type, const char *id,
  * Get the value for a given PAF record name.
  */
 
-inline static int
+ static int
 _pilPAFGetValueBool(PilList *list, const char *name)
 {
 
@@ -475,7 +475,7 @@ _pilPAFGetValueBool(PilList *list, const char *name)
 }
 
 
-inline static int
+ static int
 _pilPAFGetValueInt(PilList *list, const char *name)
 {
 
@@ -498,7 +498,7 @@ _pilPAFGetValueInt(PilList *list, const char *name)
 }
 
 
-inline static double
+ static double
 _pilPAFGetValueDouble(PilList *list, const char *name)
 {
 
@@ -521,7 +521,7 @@ _pilPAFGetValueDouble(PilList *list, const char *name)
 }
 
 
-inline static const char *
+ static const char *
 _pilPAFGetValueString(PilList *list, const char *name)
 {
 
@@ -548,7 +548,7 @@ _pilPAFGetValueString(PilList *list, const char *name)
  * Modify the value for a given PAF record name.
  */
 
-inline static int
+ static int
 _pilPAFSetValue(PilList *list, const char *name, PilPAFType type,
                 const void *value)
 {
@@ -608,7 +608,7 @@ _pilPAFSetValue(PilList *list, const char *name, PilPAFType type,
  * The formatted record is written to the given output buffer.
  */
 
-inline static const char *
+ static const char *
 _pilPAFFormatRecord(PilPAFRecord *record)
 {
 
@@ -731,7 +731,7 @@ _pilPAFFormatRecord(PilPAFRecord *record)
  * The function deallocates all memory used for the PAF object @em paf.
  */
 
-inline void
+ void
 deletePilPAF(PilPAF *paf)
 {
 
@@ -1195,7 +1195,7 @@ pilPAFSetHeader(PilPAF *paf, const char *name, const char *type,
  * upper case letters and it may not contain blanks.
  */
 
-inline int
+ int
 pilPAFIsValidName(const char *name)
 {
 
@@ -1644,7 +1644,7 @@ pilPAFSetComment(PilPAF *paf, const char *name, const char *comment)
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertBool(PilPAF *paf, const char *key, const char *name, int value,
                  const char *comment)
 {
@@ -1686,7 +1686,7 @@ pilPAFInsertBool(PilPAF *paf, const char *key, const char *name, int value,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertInt(PilPAF *paf, const char *key, const char *name, int value,
                 const char *comment)
 {
@@ -1728,7 +1728,7 @@ pilPAFInsertInt(PilPAF *paf, const char *key, const char *name, int value,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertDouble(PilPAF *paf, const char *key, const char *name,
                    double value, const char *comment)
 {
@@ -1770,7 +1770,7 @@ pilPAFInsertDouble(PilPAF *paf, const char *key, const char *name,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertString(PilPAF *paf, const char *key, const char *name,
                    const char *value, const char *comment)
 {
@@ -1812,7 +1812,7 @@ pilPAFInsertString(PilPAF *paf, const char *key, const char *name,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertAfterBool(PilPAF *paf, const char *key, const char *name,
                       int value, const char *comment)
 {
@@ -1854,7 +1854,7 @@ pilPAFInsertAfterBool(PilPAF *paf, const char *key, const char *name,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertAfterInt(PilPAF *paf, const char *key, const char *name,
                      int value, const char *comment)
 {
@@ -1896,7 +1896,7 @@ pilPAFInsertAfterInt(PilPAF *paf, const char *key, const char *name,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertAfterDouble(PilPAF *paf, const char *key, const char *name,
                         double value, const char *comment)
 {
@@ -1938,7 +1938,7 @@ pilPAFInsertAfterDouble(PilPAF *paf, const char *key, const char *name,
  * exist, the function fails and the value is not inserted.
  */
 
-inline int
+ int
 pilPAFInsertAfterString(PilPAF *paf, const char *key, const char *name,
                         const char *value, const char *comment)
 {
@@ -1976,7 +1976,7 @@ pilPAFInsertAfterString(PilPAF *paf, const char *key, const char *name,
  * @em paf.
  */
 
-inline int
+ int
 pilPAFPrependBool(PilPAF *paf, const char *name, int value,
                   const char *comment)
 {
@@ -2012,7 +2012,7 @@ pilPAFPrependBool(PilPAF *paf, const char *name, int value,
  * and prepends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFPrependInt(PilPAF *paf, const char *name, int value, const char *comment)
 {
 
@@ -2048,7 +2048,7 @@ pilPAFPrependInt(PilPAF *paf, const char *name, int value, const char *comment)
  * and prepends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFPrependDouble(PilPAF *paf, const char *name, double value,
                    const char *comment)
 {
@@ -2085,7 +2085,7 @@ pilPAFPrependDouble(PilPAF *paf, const char *name, double value,
  * and prepends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFPrependString(PilPAF *paf, const char *name, const char *value,
                    const char *comment)
 {
@@ -2122,7 +2122,7 @@ pilPAFPrependString(PilPAF *paf, const char *name, const char *value,
  * and appends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFAppendBool(PilPAF *paf, const char *name, int value, const char *comment)
 {
     assert(paf != NULL);
@@ -2157,7 +2157,7 @@ pilPAFAppendBool(PilPAF *paf, const char *name, int value, const char *comment)
  * and appends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFAppendInt(PilPAF *paf, const char *name, int value, const char *comment)
 {
 
@@ -2193,7 +2193,7 @@ pilPAFAppendInt(PilPAF *paf, const char *name, int value, const char *comment)
  * and appends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFAppendDouble(PilPAF *paf, const char *name, double value,
                    const char *comment)
 {
@@ -2230,7 +2230,7 @@ pilPAFAppendDouble(PilPAF *paf, const char *name, double value,
  * and appends it to the record list of the PAF object @em paf.
  */
 
-inline int
+ int
 pilPAFAppendString(PilPAF *paf, const char *name, const char *value,
                    const char *comment)
 {
@@ -2267,7 +2267,7 @@ pilPAFAppendString(PilPAF *paf, const char *name, const char *value,
  * record list only the first one is erased.
  */
 
-inline void
+ void
 pilPAFErase(PilPAF *paf, const char *name)
 {
 
@@ -2299,7 +2299,7 @@ pilPAFErase(PilPAF *paf, const char *name)
  * any way by this function.
  */
 
-inline void
+ void
 pilPAFClear(PilPAF *paf)
 {
 
