@@ -34,7 +34,7 @@
 #include <vimos_calib_mult.h>
 #include <cpl.h>
 #include <moses.h>
-#include <fors_dfs.h>
+#include <vimos_dfs.h>
 #include <fors_qc.h>
 
 #define vimos_multi_exit(message)                    \
@@ -84,7 +84,7 @@ static char vimos_calib_description[] =
 "  DO category:               Type:       Explanation:         Required:\n"
 "  MOS_SCREEN_FLAT            Raw         Flat field exposures    Y\n"
 "  MOS_ARC_SPECTRUM           Raw         Arc lamp exposure       Y\n"
-"  MASTER_BIAS or BIAS        Calib       Bias frame              Y\n"
+"  MASTER_BIAS                Calib       Bias frame              Y\n"
 "  LINE_CATALOG               Calib       Line catalog            Y\n"
 "  CONFIG_TABLE               Calib       Grism table             .\n\n"
 "Output files:\n\n"
@@ -248,7 +248,7 @@ static int vimos_calib_create(cpl_plugin *plugin)
                                 "Rejection threshold in dispersion "
                                 "relation fit (pixel)",
                                 "vimos.vmmoscalib",
-                                0.7);
+                                1.);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "wreject");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
@@ -286,16 +286,31 @@ static int vimos_calib_create(cpl_plugin *plugin)
 
 
     /*
-     * Line catalog table column containing the reference wavelengths
+     * Catalog lines to ignore in wavelength calibration
      */
 
-    p = cpl_parameter_new_value("vimos.vmmoscalib.wcolumn",
+    p = cpl_parameter_new_value("vimos.vmmoscalib.ignore_lines",
                                 CPL_TYPE_STRING,
-                                "Name of line catalog table column "
-                                "with wavelengths",
+                                "Catalog lines nearest to wavelengths in this "
+                                "list will be ignored for wavelength calibration",
                                 "vimos.vmmoscalib",
-                                "WLEN");
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "wcolumn");
+                                "");
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "ignore_lines");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+    /*
+     * Linesets to use
+     */
+
+    p = cpl_parameter_new_value("vimos.vmmoscalib.used_linesets",
+                                CPL_TYPE_STRING,
+                                "Linesets to use. Valid are 'standard' and"
+                                "'extended' (see column LINE_SET in the "
+                                "line catalogue)",
+                                "vimos.vmmoscalib",
+                                "standard");
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "used_linesets");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
@@ -360,7 +375,7 @@ static int vimos_calib_create(cpl_plugin *plugin)
 
     p = cpl_parameter_new_value("vimos.vmmoscalib.reference",
                                 CPL_TYPE_DOUBLE,
-                                "Reference wavelength for calibration",
+                                "Reference wavelength for slit map",
                                 "vimos.vmmoscalib",
                                 0.0);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "reference");
@@ -373,7 +388,12 @@ static int vimos_calib_create(cpl_plugin *plugin)
 
     p = cpl_parameter_new_value("vimos.vmmoscalib.slit_ident",
                                 CPL_TYPE_BOOL,
-                                "Attempt slit identification",
+                                "Attempt slit identification."
+                                "For multiplexing data slit identification "
+                                "is always performed. Switching it off will "
+                                "cause systematic errors in the absolute flux "
+                                "calibration if the FLAT_SED correction is "
+                                "used (see pipeline manual for details)",
                                 "vimos.vmmoscalib",
                                 TRUE);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "slit_ident");
@@ -381,34 +401,45 @@ static int vimos_calib_create(cpl_plugin *plugin)
     cpl_parameterlist_append(recipe->parameters, p);
 
     /*
-     * Degree of flat field fitting polynomial along spatial direction 
-     * (used for LSS data)
+     * Polynomial degree for flat field polynomial fitting along spatial direction 
      */
 
-    p = cpl_parameter_new_value("vimos.vmmoscalib.sdegree",
+    p = cpl_parameter_new_value("vimos.vmmoscalib.s_degree",
                                 CPL_TYPE_INT,
-                                "Degree of flat field fitting polynomial "
-                                "along spatial direction (used for LSS-like "
-                                "data only)",
+                                "Polynomial degree for the flat field fitting "
+                                "along spatial direction",
                                 "vimos.vmmoscalib",
                                 -1);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "sdegree");
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "s_degree");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
     /*
-     * Degree of flat field fitting polynomial along dispersion direction
-     * (used for MOS data)
+     * Smooth box radius for flat field along spatial direction
+     * (if s_knots < 0)
      */
 
-    p = cpl_parameter_new_value("vimos.vmmoscalib.ddegree",
+    p = cpl_parameter_new_value("vimos.vmmoscalib.sradius",
                                 CPL_TYPE_INT,
-                                "Degree of flat field fitting polynomial "
-                                "along dispersion direction (not used for "
-                                "long-slit-like data)",
+                                "Smooth box radius for flat field along "
+                                "spatial direction (used if s_knots < 0)",
                                 "vimos.vmmoscalib",
                                 -1);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "ddegree");
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "sradius");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+    /*
+     * Number of knots in flat field fitting splines along dispersion direction 
+     */
+
+    p = cpl_parameter_new_value("vimos.vmmoscalib.d_nknots",
+                                CPL_TYPE_INT,
+                                "Number of knots in flat field fitting "
+                                "splines along dispersion direction",
+                                "vimos.vmmoscalib",
+                                -1);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "d_nknots");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
@@ -419,7 +450,7 @@ static int vimos_calib_create(cpl_plugin *plugin)
     p = cpl_parameter_new_value("vimos.vmmoscalib.dradius",
                                 CPL_TYPE_INT,
                                 "Smooth box radius for flat field along "
-                                "dispersion direction",
+                                "dispersion direction (if d_knots < 0)",
                                 "vimos.vmmoscalib",
                                 10);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "dradius");
@@ -427,20 +458,35 @@ static int vimos_calib_create(cpl_plugin *plugin)
     cpl_parameterlist_append(recipe->parameters, p);
 
     /*
-     * Smooth box radius for flat field along spatial direction
-     * (used for LSS data only)
+     * Threshold percentage for flat spline fitting with respect to the maximum
      */
 
-    p = cpl_parameter_new_value("vimos.vmmoscalib.sradius",
-                                CPL_TYPE_INT,
-                                "Smooth box radius for flat field along "
-                                "spatial direction",
+    p = cpl_parameter_new_value("vimos.vmmoscalib.fit_threshold",
+                                CPL_TYPE_DOUBLE,
+                                "Threshold percentage for flat spline fitting "
+                                "with respect to the maximum",
                                 "vimos.vmmoscalib",
-                                10);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "sradius");
+                                0.01);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "fit_threshold");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
+    /*
+     * Tolerance used for ratios during line identification 
+     */
+
+    p = cpl_parameter_new_value("vimos.vmmoscalib.line_ident_tol",
+                                CPL_TYPE_DOUBLE,
+                                "Tolerance for the ratio of detected lines "
+                                "vs reference lines. This is used during "
+                                "for arc line identification.",
+                                "vimos.vmmoscalib",
+                                0.05);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "line_ident_tol");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+
     return 0;
 }
 
@@ -527,7 +573,7 @@ static int vimos_calib(cpl_parameterlist *parlist, cpl_frameset *frameset)
     if (header == NULL)
         vimos_multi_exit("Cannot load arc lamp header");
 
-    maskslits = mos_load_slits_vimos(header);
+    maskslits = mos_load_slits_vimos(header, 0);
     cpl_propertylist_delete(header); header = NULL;
     multiplex = mos_check_multiplex(maskslits);
 //    cpl_table_save(maskslits, NULL, NULL, "groups.fits", CPL_IO_DEFAULT);
