@@ -59,6 +59,7 @@
 #include "vmimgutils.h"
 #include "vmqcutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 #define MAX_COMMENT_LENGTH  (80)
@@ -988,7 +989,7 @@ vmimflatscreen(PilSetOfFrames *sof)
 
   error = 1;
 
-  flatList = (VimosImage **)pil_calloc(flatCount, sizeof(VimosImage *));
+  flatList = (VimosImage **)cpl_calloc(flatCount, sizeof(VimosImage *));
   if (flatList) {
 
     error = 0;
@@ -1005,7 +1006,7 @@ vmimflatscreen(PilSetOfFrames *sof)
                     "Failure opening screen flat field frame %d", i + 1);
         for (j = 0; j < i; j++) 
           deleteImage(flatList[j]);
-        pil_free(flatList);
+        cpl_free(flatList);
         break;
       }
       currFrame = pilSofLookupNext(sof, NULL);
@@ -1036,7 +1037,7 @@ vmimflatscreen(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure in growing overscans in master bias");
     for (i = 0; i < flatCount; i++) 
       deleteImage(flatList[i]);
-    pil_free(flatList);
+    cpl_free(flatList);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteCcdTable(ccdTable);
@@ -1050,7 +1051,7 @@ vmimflatscreen(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((exposureTime = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((exposureTime = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     error = 0;
     for (i = 0; i < flatCount; i++) {
       if ((readDoubleDescriptor(flatList[i]->descs,
@@ -1060,7 +1061,7 @@ vmimflatscreen(PilSetOfFrames *sof)
           error = 1;
           cpl_msg_error(task, 
             "Zero or negative exposure time for flat field %d", i + 1);
-          pil_free(exposureTime);
+          cpl_free(exposureTime);
           break;
         }
         else {
@@ -1071,7 +1072,7 @@ vmimflatscreen(PilSetOfFrames *sof)
         error = 1;
         cpl_msg_error(task, "Cannot read %s from flat field frame %d", 
                     pilTrnGetKeyword("ExposureTime"), i + 1);
-        pil_free(exposureTime);
+        cpl_free(exposureTime);
         break;
       }
     }
@@ -1082,7 +1083,7 @@ vmimflatscreen(PilSetOfFrames *sof)
   if (error) {
     for (j = 0; j < flatCount; j++)
       deleteImage(flatList[j]);
-    pil_free(flatList);
+    cpl_free(flatList);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteCcdTable(ccdTable);
@@ -1096,7 +1097,7 @@ vmimflatscreen(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((flatGain = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatGain = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     error = 0;
     for (i = 0; i < flatCount; i++) {
       gain = getMeanGainFactor(flatList[i]);
@@ -1106,7 +1107,7 @@ vmimflatscreen(PilSetOfFrames *sof)
       else {
         error = 1;
         cpl_msg_error(task, "Wrong or no gain factor for flat field %d", i + 1);
-        pil_free(flatGain);
+        cpl_free(flatGain);
         break;
       }
     }
@@ -1117,8 +1118,8 @@ vmimflatscreen(PilSetOfFrames *sof)
   if (error) {
     for (j = 0; j < flatCount; j++)
       deleteImage(flatList[j]);
-    pil_free(flatList);
-    pil_free(exposureTime);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteCcdTable(ccdTable);
@@ -1132,7 +1133,7 @@ vmimflatscreen(PilSetOfFrames *sof)
   * etc.) is applied.
   */
 
-  if ((flatRon = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatRon = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     for (i = 0; i < flatCount; i++) {
       flatRon[i] = computeAverageRon(flatList[i]);
     }
@@ -1142,16 +1143,16 @@ vmimflatscreen(PilSetOfFrames *sof)
 
     for (i = 0; i < flatCount; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
-    pil_free(exposureTime);
-    pil_free(flatGain);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
+    cpl_free(flatGain);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
 
-  if ((flatNoise = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatNoise = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     for (i = 0; i < flatCount; i++) {
       flatNoise[i] = evaluateAverageNoise(flatList[i], 
                      flatRon[i], flatGain[i]);
@@ -1162,10 +1163,10 @@ vmimflatscreen(PilSetOfFrames *sof)
 
     for (i = 0; i < flatCount; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
-    pil_free(exposureTime);
-    pil_free(flatGain);
-    pil_free(flatRon);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
+    cpl_free(flatGain);
+    cpl_free(flatRon);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteCcdTable(ccdTable);
@@ -1173,9 +1174,16 @@ vmimflatscreen(PilSetOfFrames *sof)
   }
 
 
- /*
-  * Now go for the bias subtraction
-  */
+  /*
+   * Now go for the bias subtraction
+   * 
+   * NOTE: This includes the overscan subtraction if biasMethod = BIAS_ZMASTER,
+   * which is the default. Since the overscan region in the master bias has 
+   * been created with growOverscans, there is some extra noise added here,
+   * but this can probably be ignored. A better approach is to use the method
+   * used in the MOS pipeline: subtract overscan for each individual frame,
+   * then subtract bias.
+   */
 
   cpl_msg_info(task, "Bias removal...");
 
@@ -1184,11 +1192,11 @@ vmimflatscreen(PilSetOfFrames *sof)
       cpl_msg_error(task, "Cannot remove bias from input flat field %d", i + 1);
       for (i = 0; i < flatCount; i++)
         deleteImage(flatList[i]);
-      pil_free(flatList);
-      pil_free(exposureTime);
-      pil_free(flatGain);
-      pil_free(flatRon);
-      pil_free(flatNoise);
+      cpl_free(flatList);
+      cpl_free(exposureTime);
+      cpl_free(flatGain);
+      cpl_free(flatRon);
+      cpl_free(flatNoise);
       deleteImage(biasImage);
       deleteImage(darkImage);
       deleteCcdTable(ccdTable);
@@ -1212,11 +1220,11 @@ vmimflatscreen(PilSetOfFrames *sof)
                     "Cannot subtract dark from input flat field %d", i + 1);
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(exposureTime);
-        pil_free(flatGain);
-        pil_free(flatRon);
-        pil_free(flatNoise);
+        cpl_free(flatList);
+        cpl_free(exposureTime);
+        cpl_free(flatGain);
+        cpl_free(flatRon);
+        cpl_free(flatNoise);
         deleteImage(darkImage);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
@@ -1230,7 +1238,7 @@ vmimflatscreen(PilSetOfFrames *sof)
   * Now flat fields levels can be computed
   */
 
-  if ((flatLevel = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatLevel = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     for (i = 0; i < flatCount; i++) {
       flatLevel[i] = imageMedian(flatList[i]);
       cpl_msg_info(task, "Level of flat field %-d is %10.4f +/- %-.4f ADU",
@@ -1241,11 +1249,11 @@ vmimflatscreen(PilSetOfFrames *sof)
     cpl_msg_error(task, "Problems with memory allocation");
     for (i = 0; i < flatCount; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
-    pil_free(flatGain);
-    pil_free(flatRon);
-    pil_free(flatNoise);
-    pil_free(exposureTime);
+    cpl_free(flatList);
+    cpl_free(flatGain);
+    cpl_free(flatRon);
+    cpl_free(flatNoise);
+    cpl_free(exposureTime);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
@@ -1267,12 +1275,12 @@ vmimflatscreen(PilSetOfFrames *sof)
                     "flat field frame %d", i + 1);
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(flatNoise);
-        pil_free(flatGain);
-        pil_free(flatRon);
-        pil_free(flatLevel);
-        pil_free(exposureTime);
+        cpl_free(flatList);
+        cpl_free(flatNoise);
+        cpl_free(flatGain);
+        cpl_free(flatRon);
+        cpl_free(flatLevel);
+        cpl_free(exposureTime);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
       }
@@ -1280,8 +1288,8 @@ vmimflatscreen(PilSetOfFrames *sof)
     }
   }
 
-  pil_free(flatRon);
-  pil_free(flatGain);
+  cpl_free(flatRon);
+  cpl_free(flatGain);
 
   if (validateFrames) {
 
@@ -1298,7 +1306,7 @@ vmimflatscreen(PilSetOfFrames *sof)
 
     cpl_msg_info(task, "Selecting good flat field frames ...");
 
-    original = (VimosImage **)pil_calloc(flatCount, sizeof(VimosImage *));
+    original = (VimosImage **)cpl_calloc(flatCount, sizeof(VimosImage *));
     if (original) {
       for (i = 0; i < flatCount; i++)
         original[i] = flatList[i];     /* Hold original image sorting */
@@ -1339,11 +1347,11 @@ vmimflatscreen(PilSetOfFrames *sof)
         cpl_msg_error(task, "Problems remapping arrays after frame selection");
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(original);
-        pil_free(flatNoise);
-        pil_free(flatLevel);
-        pil_free(exposureTime);
+        cpl_free(flatList);
+        cpl_free(original);
+        cpl_free(flatNoise);
+        cpl_free(flatLevel);
+        cpl_free(exposureTime);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
       }
@@ -1388,11 +1396,11 @@ vmimflatscreen(PilSetOfFrames *sof)
         cpl_msg_error(task, "Problems remapping arrays after frame selection");
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(original);
-        pil_free(flatNoise);
-        pil_free(flatLevel);
-        pil_free(exposureTime);
+        cpl_free(flatList);
+        cpl_free(original);
+        cpl_free(flatNoise);
+        cpl_free(flatLevel);
+        cpl_free(exposureTime);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
       }
@@ -1403,7 +1411,7 @@ vmimflatscreen(PilSetOfFrames *sof)
                  "selected from input set", goodFrames, flatCount);
     }
 
-    pil_free(original);
+    cpl_free(original);
 
   }
   else
@@ -1416,13 +1424,13 @@ vmimflatscreen(PilSetOfFrames *sof)
 
   for (i = goodFrames; i < flatCount; i++)
     deleteImage(flatList[i]);
-  pil_free(flatNoise);
+  cpl_free(flatNoise);
 
   if (!goodFrames) {
     cpl_msg_error(task, "No screen flat field frames with consistent signal "
                 "distribution found in input. All frames excluded!");
-    pil_free(flatList);
-    pil_free(exposureTime);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
   }
@@ -1466,22 +1474,22 @@ vmimflatscreen(PilSetOfFrames *sof)
 
     for (i = 0; i < goodFrames; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
+    cpl_free(flatList);
     deleteCcdTable(ccdTable);
-    pil_free(exposureTime);
-    pil_free(flatLevel);
+    cpl_free(exposureTime);
+    cpl_free(flatLevel);
     return EXIT_FAILURE;
   }
 
-  pil_free(flatLevel);
+  cpl_free(flatLevel);
 
   if (!mFlat) {
     cpl_msg_error(task, "Stacking of raw screen flat field frames failure!");
     deleteCcdTable(ccdTable);
-    pil_free(exposureTime);
+    cpl_free(exposureTime);
     for (i = 0; i < goodFrames; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
+    cpl_free(flatList);
     return EXIT_FAILURE;
   }
 
@@ -1545,7 +1553,7 @@ vmimflatscreen(PilSetOfFrames *sof)
         float       *sample2 = extractFloatImage(flatList[1]->data,
                                flatList[1]->xlen, flatList[1]->ylen,
                                winStartX, winStartY, winSizeX, winSizeY);
-        float       *diff    = pil_malloc(winSizeX * winSizeY * sizeof(float));
+        float       *diff    = cpl_malloc(winSizeX * winSizeY * sizeof(float));
         float       *convFactors;
         float       *box;
         float       *diffBox;
@@ -1557,10 +1565,10 @@ vmimflatscreen(PilSetOfFrames *sof)
 
         if (!(sample1 && sample2 && diff)) {
           cpl_msg_error(task, "Memory allocation!");
-          pil_free(exposureTime);
+          cpl_free(exposureTime);
           for (i = 0; i < goodFrames; i++)
             deleteImage(flatList[i]);
-          pil_free(flatList);
+          cpl_free(flatList);
           deleteCcdTable(ccdTable);
           return EXIT_FAILURE;
         }
@@ -1569,13 +1577,13 @@ vmimflatscreen(PilSetOfFrames *sof)
                               &quadrant, NULL) == VM_FALSE) {
           cpl_msg_error(task, "Integer descriptor %s not found",
                       pilTrnGetKeyword("Quadrant"));
-          pil_free(sample1);
-          pil_free(sample2);
-          pil_free(diff);
-          pil_free(exposureTime);
+          cpl_free(sample1);
+          cpl_free(sample2);
+          cpl_free(diff);
+          cpl_free(exposureTime);
           for (i = 0; i < goodFrames; i++)
             deleteImage(flatList[i]);
-          pil_free(flatList);
+          cpl_free(flatList);
           deleteCcdTable(ccdTable);
           return EXIT_FAILURE;
         }
@@ -1605,18 +1613,18 @@ vmimflatscreen(PilSetOfFrames *sof)
           for (i = 0; i < npix; i++)
             diff[i] = sample1[i] - sample2[i];
 
-          pil_free(sample2);
+          cpl_free(sample2);
 
-          convFactors = pil_malloc(ngains * sizeof(float));
+          convFactors = cpl_malloc(ngains * sizeof(float));
 
           if (!convFactors) {
             cpl_msg_error(task, "Memory allocation!");
-            pil_free(sample1);
-            pil_free(diff);
-            pil_free(exposureTime);
+            cpl_free(sample1);
+            cpl_free(diff);
+            cpl_free(exposureTime);
             for (i = 0; i < goodFrames; i++)
               deleteImage(flatList[i]);
-            pil_free(flatList);
+            cpl_free(flatList);
             deleteCcdTable(ccdTable);
             return EXIT_FAILURE;
           }
@@ -1629,12 +1637,12 @@ vmimflatscreen(PilSetOfFrames *sof)
                                           winStepX, winStepY);
 
               meanValue = medianPixelvalue(box, winStepX * winStepY);
-              pil_free(box);
+              cpl_free(box);
               value = computeVarianceFloat2D(diffBox, winStepX, winStepY);
               value /= 2;
               convFactors[i] = meanValue / value;
 
-              pil_free(diffBox);
+              cpl_free(diffBox);
             }
           }
 
@@ -1650,7 +1658,7 @@ vmimflatscreen(PilSetOfFrames *sof)
 
           meanValue = medianPixelvalue(convFactors, ngains);
 
-          pil_free(convFactors);
+          cpl_free(convFactors);
 
           qcWriteValueDouble(mFlat->descs, meanValue, "QC.CONAD", "e-/ADU", 
                              "Conversion factor from electrons to ADU");
@@ -1672,10 +1680,10 @@ vmimflatscreen(PilSetOfFrames *sof)
 
           if (!sample2) {
             cpl_msg_error(task, "Memory allocation!");
-            pil_free(exposureTime);
+            cpl_free(exposureTime);
             for (i = 0; i < goodFrames; i++)
               deleteImage(flatList[i]);
-            pil_free(flatList);
+            cpl_free(flatList);
             deleteCcdTable(ccdTable);
             return EXIT_FAILURE;
           }
@@ -1683,7 +1691,7 @@ vmimflatscreen(PilSetOfFrames *sof)
           for (i = 0; i < npix; i++)
             diff[i] = sample1[i] - sample2[i];
 
-          pil_free(sample2);
+          cpl_free(sample2);
 
           value = computeVarianceFloat2D(diff, winSizeX, winSizeY);
           value /= 2;
@@ -1695,7 +1703,7 @@ vmimflatscreen(PilSetOfFrames *sof)
           qcWriteValueDouble(mFlat->descs, fpnValue, "QC.FLAT.FPN", "ADU",
                              "Fixed pattern noise");
 
-          pil_free(diff);
+          cpl_free(diff);
 
           meanValue = computeAverageFloat(sample1, npix);
 
@@ -1717,7 +1725,7 @@ vmimflatscreen(PilSetOfFrames *sof)
           qcWriteValueDouble(mFlat->descs, value, "QC.FLAT.EFFICIENCY", 
                              "ADU/s", "Signal per unit exposure");
 
-          pil_free(sample1);
+          cpl_free(sample1);
 
           /*
            * QC.FLAT.MASTER.MEDIAN 
@@ -1732,10 +1740,10 @@ vmimflatscreen(PilSetOfFrames *sof)
 
           if (!(sample1 && sample2 && diff)) {
             cpl_msg_error(task, "Memory allocation!");
-            pil_free(exposureTime);
+            cpl_free(exposureTime);
             for (i = 0; i < goodFrames; i++)
               deleteImage(flatList[i]);
-            pil_free(flatList);
+            cpl_free(flatList);
             deleteCcdTable(ccdTable);
             return EXIT_FAILURE;
           }
@@ -1783,11 +1791,11 @@ vmimflatscreen(PilSetOfFrames *sof)
   for (i = 0; i < goodFrames; i++)
     sumExposures += exposureTime[i];
 
-  pil_free(exposureTime);
+  cpl_free(exposureTime);
 
   for (i = 0; i < goodFrames; i++)
     deleteImage(flatList[i]);
-  pil_free(flatList);
+  cpl_free(flatList);
 
   cpl_msg_info(task, "Master screen flat field trend removal...");
 
@@ -1857,7 +1865,7 @@ vmimflatscreen(PilSetOfFrames *sof)
    * Output the normalized master screen flat field.
    */
 
-  strlower(strcpy(mFlatName, mFlatTag));
+  vmstrlower(strcpy(mFlatName, mFlatTag));
   strcat(mFlatName, ".fits");
 
   /* FIXME: Is this really applicable */
@@ -1951,7 +1959,7 @@ vmimflatscreen(PilSetOfFrames *sof)
   * Output the combination of the raw flat fields
   */
 
-  strlower(strcpy(cFlatName, cFlatTag));
+  vmstrlower(strcpy(cFlatName, cFlatTag));
   strcat(cFlatName, ".fits");
 
   /* FIXME: Is this really applicable */
