@@ -59,6 +59,7 @@
 #include "vmimgutils.h"
 #include "vmqcutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 #define MAX_COMMENT_LENGTH  (80)
@@ -1034,7 +1035,7 @@ vmimflatsky(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((flatList = (VimosImage **)pil_calloc(flatCount, sizeof(VimosImage *)))) {
+  if ((flatList = (VimosImage **)cpl_calloc(flatCount, sizeof(VimosImage *)))) {
 
     error = 0;
     currFrame = pilSofLookupNext(sof, flatTag);
@@ -1049,7 +1050,7 @@ vmimflatsky(PilSetOfFrames *sof)
         cpl_msg_error(task, "Failure opening sky flat field frame %d", i + 1);
         for (j = 0; j < i; j++) 
           deleteImage(flatList[j]);
-        pil_free(flatList);
+        cpl_free(flatList);
         break;
       }
       currFrame = pilSofLookupNext(sof, NULL);
@@ -1081,7 +1082,7 @@ vmimflatsky(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure in growing overscans in master bias");
     for (i = 0; i < flatCount; i++) 
       deleteImage(flatList[i]);
-    pil_free(flatList);
+    cpl_free(flatList);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteImage(screenImage);
@@ -1096,7 +1097,7 @@ vmimflatsky(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((exposureTime = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((exposureTime = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     error = 0;
     for (i = 0; i < flatCount; i++) {
       if ((readDoubleDescriptor(flatList[i]->descs, 
@@ -1106,7 +1107,7 @@ vmimflatsky(PilSetOfFrames *sof)
           error = 1;
           cpl_msg_error(task, 
             "Zero or negative exposure time for flat field %d", i + 1);
-          pil_free(exposureTime);
+          cpl_free(exposureTime);
           break;
         }
         else {
@@ -1117,7 +1118,7 @@ vmimflatsky(PilSetOfFrames *sof)
         error = 1;
         cpl_msg_error(task, "Cannot read %s from flat field frame %d", 
                     pilTrnGetKeyword("ExposureTime"), i + 1);
-        pil_free(exposureTime);
+        cpl_free(exposureTime);
         break;
       }
     }
@@ -1128,7 +1129,7 @@ vmimflatsky(PilSetOfFrames *sof)
   if (error) {
     for (j = 0; j < flatCount; j++)
       deleteImage(flatList[j]);
-    pil_free(flatList);
+    cpl_free(flatList);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteImage(screenImage);
@@ -1143,7 +1144,7 @@ vmimflatsky(PilSetOfFrames *sof)
 
   error = 1;
 
-  if ((flatGain = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatGain = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     error = 0;
     for (i = 0; i < flatCount; i++) {
       gain = getMeanGainFactor(flatList[i]);
@@ -1153,7 +1154,7 @@ vmimflatsky(PilSetOfFrames *sof)
       else {
         error = 1;
         cpl_msg_error(task, "Wrong or no gain factor for flat field %d", i + 1);
-        pil_free(flatGain);
+        cpl_free(flatGain);
         break;
       }
     }
@@ -1164,8 +1165,8 @@ vmimflatsky(PilSetOfFrames *sof)
   if (error) {
     for (j = 0; j < flatCount; j++)
       deleteImage(flatList[j]);
-    pil_free(flatList);
-    pil_free(exposureTime);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteImage(screenImage);
@@ -1180,7 +1181,7 @@ vmimflatsky(PilSetOfFrames *sof)
   * etc.) is applied.
   */
 
-  if ((flatRon = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatRon = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     for (i = 0; i < flatCount; i++) {
       flatRon[i] = computeAverageRon(flatList[i]);
     }
@@ -1190,9 +1191,9 @@ vmimflatsky(PilSetOfFrames *sof)
 
     for (i = 0; i < flatCount; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
-    pil_free(exposureTime);
-    pil_free(flatGain);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
+    cpl_free(flatGain);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteImage(screenImage);
@@ -1200,7 +1201,7 @@ vmimflatsky(PilSetOfFrames *sof)
     return EXIT_FAILURE;
   }
 
-  if ((flatNoise = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatNoise = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     for (i = 0; i < flatCount; i++) {
       flatNoise[i] = evaluateAverageNoise(flatList[i], 
                      flatRon[i], flatGain[i]);
@@ -1211,10 +1212,10 @@ vmimflatsky(PilSetOfFrames *sof)
 
     for (i = 0; i < flatCount; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
-    pil_free(exposureTime);
-    pil_free(flatGain);
-    pil_free(flatRon);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
+    cpl_free(flatGain);
+    cpl_free(flatRon);
     deleteImage(biasImage);
     deleteImage(darkImage);
     deleteImage(screenImage);
@@ -1223,9 +1224,16 @@ vmimflatsky(PilSetOfFrames *sof)
   }
 
 
- /*
-  * Now go for the bias subtraction
-  */
+  /*
+   * Now go for the bias subtraction
+   * 
+   * NOTE: This includes the overscan subtraction if biasMethod = BIAS_ZMASTER,
+   * which is the default. Since the overscan region in the master bias has 
+   * been created with growOverscans, there is some extra noise added here,
+   * but this can probably be ignored. A better approach is to use the method
+   * used in the MOS pipeline: subtract overscan for each individual frame,
+   * then subtract bias.
+   */
 
   cpl_msg_info(task, "Bias removal...");
 
@@ -1234,11 +1242,11 @@ vmimflatsky(PilSetOfFrames *sof)
       cpl_msg_error(task, "Cannot remove bias from input flat field %d", i + 1);
       for (i = 0; i < flatCount; i++)
         deleteImage(flatList[i]);
-      pil_free(flatList);
-      pil_free(exposureTime);
-      pil_free(flatGain);
-      pil_free(flatRon);
-      pil_free(flatNoise);
+      cpl_free(flatList);
+      cpl_free(exposureTime);
+      cpl_free(flatGain);
+      cpl_free(flatRon);
+      cpl_free(flatNoise);
       deleteImage(biasImage);
       deleteImage(darkImage);
       deleteImage(screenImage);
@@ -1263,11 +1271,11 @@ vmimflatsky(PilSetOfFrames *sof)
                     "Cannot subtract dark from input flat field %d", i + 1);
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(exposureTime);
-        pil_free(flatGain);
-        pil_free(flatRon);
-        pil_free(flatNoise);
+        cpl_free(flatList);
+        cpl_free(exposureTime);
+        cpl_free(flatGain);
+        cpl_free(flatRon);
+        cpl_free(flatNoise);
         deleteImage(darkImage);
         deleteImage(screenImage);
         deleteCcdTable(ccdTable);
@@ -1282,7 +1290,7 @@ vmimflatsky(PilSetOfFrames *sof)
   * Now flat fields levels can be computed
   */
 
-  if ((flatLevel = (float *)pil_calloc(flatCount, sizeof(float)))) {
+  if ((flatLevel = (float *)cpl_calloc(flatCount, sizeof(float)))) {
     for (i = 0; i < flatCount; i++) {
       flatLevel[i] = imageMedian(flatList[i]);
       cpl_msg_info(task, "Level of flat field %-d is %10.4f +/- %-.4f ADU",
@@ -1293,11 +1301,11 @@ vmimflatsky(PilSetOfFrames *sof)
     cpl_msg_error(task, "Problems with memory allocation");
     for (i = 0; i < flatCount; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
-    pil_free(flatGain);
-    pil_free(flatRon);
-    pil_free(flatNoise);
-    pil_free(exposureTime);
+    cpl_free(flatList);
+    cpl_free(flatGain);
+    cpl_free(flatRon);
+    cpl_free(flatNoise);
+    cpl_free(exposureTime);
     deleteImage(screenImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
@@ -1320,12 +1328,12 @@ vmimflatsky(PilSetOfFrames *sof)
                     "flat field frame %d", i + 1);
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(flatNoise);
-        pil_free(flatGain);
-        pil_free(flatRon);
-        pil_free(flatLevel);
-        pil_free(exposureTime);
+        cpl_free(flatList);
+        cpl_free(flatNoise);
+        cpl_free(flatGain);
+        cpl_free(flatRon);
+        cpl_free(flatLevel);
+        cpl_free(exposureTime);
         deleteImage(screenImage);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
@@ -1334,8 +1342,8 @@ vmimflatsky(PilSetOfFrames *sof)
     }
   }
 
-  pil_free(flatRon);
-  pil_free(flatGain);
+  cpl_free(flatRon);
+  cpl_free(flatGain);
 
   if (validateFrames) {
 
@@ -1352,7 +1360,7 @@ vmimflatsky(PilSetOfFrames *sof)
 
     cpl_msg_info(task, "Selecting good flat field frames ...");
 
-    original = (VimosImage **)pil_calloc(flatCount, sizeof(VimosImage *));
+    original = (VimosImage **)cpl_calloc(flatCount, sizeof(VimosImage *));
     if (original) {
       for (i = 0; i < flatCount; i++)
         original[i] = flatList[i];     /* Hold original image sorting */
@@ -1393,11 +1401,11 @@ vmimflatsky(PilSetOfFrames *sof)
         cpl_msg_error(task, "Problems remapping arrays after frame selection");
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(original);
-        pil_free(flatNoise);
-        pil_free(flatLevel);
-        pil_free(exposureTime);
+        cpl_free(flatList);
+        cpl_free(original);
+        cpl_free(flatNoise);
+        cpl_free(flatLevel);
+        cpl_free(exposureTime);
         deleteImage(screenImage);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
@@ -1443,11 +1451,11 @@ vmimflatsky(PilSetOfFrames *sof)
         cpl_msg_error(task, "Problems remapping arrays after frame selection");
         for (i = 0; i < flatCount; i++)
           deleteImage(flatList[i]);
-        pil_free(flatList);
-        pil_free(original);
-        pil_free(flatNoise);
-        pil_free(flatLevel);
-        pil_free(exposureTime);
+        cpl_free(flatList);
+        cpl_free(original);
+        cpl_free(flatNoise);
+        cpl_free(flatLevel);
+        cpl_free(exposureTime);
         deleteImage(screenImage);
         deleteCcdTable(ccdTable);
         return EXIT_FAILURE;
@@ -1459,7 +1467,7 @@ vmimflatsky(PilSetOfFrames *sof)
                  "selected from input set", goodFrames, flatCount);
     }
 
-    pil_free(original);
+    cpl_free(original);
 
   }
   else {
@@ -1483,13 +1491,13 @@ vmimflatsky(PilSetOfFrames *sof)
 
   for (i = goodFrames; i < flatCount; i++)
     deleteImage(flatList[i]);
-  pil_free(flatNoise);
+  cpl_free(flatNoise);
 
   if (!goodFrames) {
     cpl_msg_error(task, "No sky flat field frames with consistent signal "
                 "distribution found in input. All frames excluded!");
-    pil_free(flatList);
-    pil_free(exposureTime);
+    cpl_free(flatList);
+    cpl_free(exposureTime);
     deleteImage(screenImage);
     deleteCcdTable(ccdTable);
     return EXIT_FAILURE;
@@ -1535,26 +1543,26 @@ vmimflatsky(PilSetOfFrames *sof)
   else {
     cpl_msg_error(task, "Not enough good frames for combine method "
                     "'%s'!", combMethodNames[combMethodEntry]);
-    pil_free(exposureTime);
+    cpl_free(exposureTime);
     for (i = 0; i < goodFrames; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
+    cpl_free(flatList);
     deleteImage(screenImage);
     deleteCcdTable(ccdTable);
-    pil_free(flatLevel);
+    cpl_free(flatLevel);
     return EXIT_FAILURE;
   }
 
-  pil_free(flatLevel);
+  cpl_free(flatLevel);
 
   if (!mFlat) {
     cpl_msg_error(task, "Stacking of raw sky flat field frames failure!");
     deleteImage(screenImage);
     deleteCcdTable(ccdTable);
-    pil_free(exposureTime);
+    cpl_free(exposureTime);
     for (i = 0; i < goodFrames; i++)
       deleteImage(flatList[i]);
-    pil_free(flatList);
+    cpl_free(flatList);
     return EXIT_FAILURE;
   }
 
@@ -1613,11 +1621,11 @@ vmimflatsky(PilSetOfFrames *sof)
                           &quadrant, NULL) == VM_FALSE) {
       cpl_msg_error(task, "Integer descriptor %s not found",
                   pilTrnGetKeyword("Quadrant"));
-      pil_free(exposureTime);
+      cpl_free(exposureTime);
 
       for (i = 0; i < goodFrames; i++)
         deleteImage(flatList[i]);
-      pil_free(flatList);
+      cpl_free(flatList);
 
       deleteImage(screenImage);
       deleteCcdTable(ccdTable);
@@ -1635,11 +1643,11 @@ vmimflatsky(PilSetOfFrames *sof)
         if (!sample1) {
           cpl_msg_error(task, "Memory allocation!");
 
-          pil_free(exposureTime);
+          cpl_free(exposureTime);
 
           for (i = 0; i < goodFrames; i++)
             deleteImage(flatList[i]);
-          pil_free(flatList);
+          cpl_free(flatList);
 
           deleteImage(screenImage);
           deleteCcdTable(ccdTable);
@@ -1682,7 +1690,7 @@ vmimflatsky(PilSetOfFrames *sof)
                              "ADU/s", "Mean sky flux") == EXIT_FAILURE)
           cpl_msg_error(task, "Could not copy value to QC1 PAF! (Ignored)");
 
-        pil_free(sample1);
+        cpl_free(sample1);
 
         if (pilQcGroupEnd() == EXIT_FAILURE)
           cpl_msg_error(task, "Cannot create QC1 PAF file! (Ignored)");
@@ -1702,11 +1710,11 @@ vmimflatsky(PilSetOfFrames *sof)
 
   for (i = 0; i < goodFrames; i++)
     sumExposures += exposureTime[i];
-  pil_free(exposureTime);
+  cpl_free(exposureTime);
 
   for (i = 0; i < goodFrames; i++)
     deleteImage(flatList[i]);
-  pil_free(flatList);
+  cpl_free(flatList);
 
   if (screenImage) {
     cpl_msg_info(task, "Smooth the combined flat field...");
@@ -1796,7 +1804,7 @@ vmimflatsky(PilSetOfFrames *sof)
     float       *sample2 = extractFloatImage(mFlatNorm->data,
                            mFlatNorm->xlen, mFlatNorm->ylen,
                            winStartX + 10, winStartY + 10, winSizeX, winSizeY);
-    float       *diff    = pil_malloc(winSizeX * winSizeY * sizeof(float));
+    float       *diff    = cpl_malloc(winSizeX * winSizeY * sizeof(float));
 
 
     if (!(sample1 && sample2 && diff)) {
@@ -1843,8 +1851,8 @@ vmimflatsky(PilSetOfFrames *sof)
       for (i = 0; i < npix; i++)
         diff[i] = sample1[i] - sample2[i];
 
-      pil_free(sample1);
-      pil_free(sample2);
+      cpl_free(sample1);
+      cpl_free(sample2);
 
       value = computeVarianceFloat2D(diff, winSizeX, winSizeY);
       value /= 2.;
@@ -1859,7 +1867,7 @@ vmimflatsky(PilSetOfFrames *sof)
       qcWriteValueDouble(mFlatNorm->descs, structValue, "QC.SKY.FLAT.STRUCT", 
                          NULL, "Structure of master sky flat field");
 
-      pil_free(diff);
+      cpl_free(diff);
 
       if (pilQcGroupEnd() == EXIT_FAILURE)
         cpl_msg_error(task, "Cannot create QC1 PAF file! (Ignored)");
@@ -1969,7 +1977,7 @@ vmimflatsky(PilSetOfFrames *sof)
    * update the set of frames.
    */
 
-  strlower(strcpy(masterFlatName, mflatTag));
+  vmstrlower(strcpy(masterFlatName, mflatTag));
   strcat(masterFlatName, ".fits");
 
   if (createFitsImage(masterFlatName, mFlatNorm, mflatTag) == VM_FALSE) {
