@@ -74,6 +74,7 @@
 #include "vmmossphotcalib.h"
 #include "vmmosutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 #define MAX_COMMENT_LENGTH (80)
@@ -730,7 +731,7 @@ vmmoscombine(PilSetOfFrames *sof)
     return EXIT_FAILURE;
   }
 
-  if ((mosList2D = (VimosImage **)pil_calloc(mosCount, sizeof(VimosImage *)))) {
+  if ((mosList2D = (VimosImage **)cpl_calloc(mosCount, sizeof(VimosImage *)))) {
 
     mosFrame = pilSofLookupNext(sof, mosExtractedCategory);
 
@@ -744,7 +745,7 @@ vmmoscombine(PilSetOfFrames *sof)
                       i + 1);
         for (j = 0; j < i; j++)
           deleteImage(mosList2D[j]);
-        pil_free(mosList2D);
+        cpl_free(mosList2D);
         return EXIT_FAILURE;
       }
       mosFrame = pilSofLookupNext(sof, NULL);
@@ -762,7 +763,7 @@ vmmoscombine(PilSetOfFrames *sof)
                   pilTrnGetKeyword("Quadrant"));
     for (i = 0; i < mosCount; i++)
       deleteImage(mosList2D[i]);
-    pil_free(mosList2D);
+    cpl_free(mosList2D);
     return EXIT_FAILURE;
   }
 
@@ -786,7 +787,7 @@ vmmoscombine(PilSetOfFrames *sof)
                     pilTrnGetKeyword("MaskId", quadrant));
     for (i = 0; i < mosCount; i++)
       deleteImage(mosList2D[i]);
-    pil_free(mosList2D);
+    cpl_free(mosList2D);
     return EXIT_FAILURE;
   }
 
@@ -810,8 +811,8 @@ vmmoscombine(PilSetOfFrames *sof)
    * truExpTime are coincident.
    */
 
-  appExpTime = (double *)pil_calloc(mosCount, sizeof(double));
-  truExpTime = (double *)pil_calloc(mosCount, sizeof(double));
+  appExpTime = (double *)cpl_calloc(mosCount, sizeof(double));
+  truExpTime = (double *)cpl_calloc(mosCount, sizeof(double));
 
   sumExpTime = 0.0;
   for (i = 0; i < mosCount; i++) {
@@ -861,9 +862,9 @@ vmmoscombine(PilSetOfFrames *sof)
   if (error) {
     for (i = 0; i < mosCount; i++)
       deleteImage(mosList2D[i]);
-    pil_free(mosList2D);
-    pil_free(appExpTime);
-    pil_free(truExpTime);
+    cpl_free(mosList2D);
+    cpl_free(appExpTime);
+    cpl_free(truExpTime);
     return EXIT_FAILURE;
   }
 
@@ -877,9 +878,9 @@ vmmoscombine(PilSetOfFrames *sof)
     deleteTable(grismTable);
     for (j = 0; j < mosCount; j++)
       deleteImage(mosList2D[j]);
-    pil_free(mosList2D);
-    pil_free(appExpTime);
-    pil_free(truExpTime);
+    cpl_free(mosList2D);
+    cpl_free(appExpTime);
+    cpl_free(truExpTime);
     return EXIT_FAILURE;
   }
 
@@ -896,7 +897,7 @@ vmmoscombine(PilSetOfFrames *sof)
 
     cpl_msg_info(task, "Loading %d input window tables...", winCount);
 
-    winList = (VimosTable **)pil_calloc(winCount, sizeof(VimosTable *));
+    winList = (VimosTable **)cpl_calloc(winCount, sizeof(VimosTable *));
 
     winFrame = pilSofLookupNext(sof, windowTableCategory);
 
@@ -919,12 +920,12 @@ vmmoscombine(PilSetOfFrames *sof)
           cpl_msg_error(task, "Failure reading window table");
           for (j = 0; j < i; j++)
             deleteTable(winList[j]);
-          pil_free(winList);
+          cpl_free(winList);
           for (j = 0; j < mosCount; j++)
             deleteImage(mosList2D[j]);
-          pil_free(mosList2D);
-          pil_free(appExpTime);
-          pil_free(truExpTime);
+          cpl_free(mosList2D);
+          cpl_free(appExpTime);
+          cpl_free(truExpTime);
           return EXIT_FAILURE;
         }
       }
@@ -947,9 +948,9 @@ vmmoscombine(PilSetOfFrames *sof)
     deleteExtractionTable(extTable);
     for (j = 0; j < mosCount; j++)
       deleteImage(mosList2D[j]);
-    pil_free(mosList2D);
-    pil_free(appExpTime);
-    pil_free(truExpTime);
+    cpl_free(mosList2D);
+    cpl_free(appExpTime);
+    cpl_free(truExpTime);
     return EXIT_FAILURE;
   }
 
@@ -958,7 +959,7 @@ vmmoscombine(PilSetOfFrames *sof)
 
   error = 0;
 
-  if ((winTablesList = (VimosWindowTable **)pil_calloc(mosCount, 
+  if ((winTablesList = (VimosWindowTable **)cpl_calloc(mosCount, 
                         sizeof(VimosWindowTable *)))) {
 
     for (i = 0; i < mosCount; i++) {
@@ -975,7 +976,7 @@ vmmoscombine(PilSetOfFrames *sof)
         deleteImage(copyMos);
         for (j = 0; j < i; j++)
           deleteWindowTable(winTablesList[j]);
-        pil_free(winTablesList);
+        cpl_free(winTablesList);
         error = 1;
         break;
       }
@@ -992,9 +993,9 @@ vmmoscombine(PilSetOfFrames *sof)
     deleteExtractionTable(extTable);
     for (j = 0; j < mosCount; j++)
       deleteImage(mosList2D[j]);
-    pil_free(mosList2D);
-    pil_free(appExpTime);
-    pil_free(truExpTime);
+    cpl_free(mosList2D);
+    cpl_free(appExpTime);
+    cpl_free(truExpTime);
     return EXIT_FAILURE;
   }
 
@@ -1029,9 +1030,9 @@ vmmoscombine(PilSetOfFrames *sof)
     deleteExtractionTable(extTable);
     for (j = 0; j < mosCount; j++)
       deleteImage(mosList2D[j]);
-    pil_free(mosList2D);
-    pil_free(appExpTime);
-    pil_free(truExpTime);
+    cpl_free(mosList2D);
+    cpl_free(appExpTime);
+    cpl_free(truExpTime);
     return EXIT_FAILURE;
   }
 
@@ -1042,9 +1043,9 @@ vmmoscombine(PilSetOfFrames *sof)
       deleteTable(atmTable);
       for (j = 0; j < mosCount; j++)
         deleteImage(mosList2D[j]);
-      pil_free(mosList2D);
-      pil_free(appExpTime);
-      pil_free(truExpTime);
+      cpl_free(mosList2D);
+      cpl_free(appExpTime);
+      cpl_free(truExpTime);
       return EXIT_FAILURE;
     }
     deleteImage(mosList2D[i]);
@@ -1104,15 +1105,15 @@ vmmoscombine(PilSetOfFrames *sof)
 
   offSets = newFloatArray(mosCount);
 
-  if (!(outSpSkyExStack = (VimosImage **)pil_calloc(2, sizeof(VimosImage *)))) {
+  if (!(outSpSkyExStack = (VimosImage **)cpl_calloc(2, sizeof(VimosImage *)))) {
     cpl_msg_error(task, "Failure in creating 2D images array");
     deleteFloatArray(offSets);
     deleteExtractionTable(extTable);
     for (j = 0; j < mosCount; j++)
       deleteImage(mosList2D[j]);
-    pil_free(mosList2D);
-    pil_free(appExpTime);
-    pil_free(truExpTime);
+    cpl_free(mosList2D);
+    cpl_free(appExpTime);
+    cpl_free(truExpTime);
     return EXIT_FAILURE;
   } 
   else {
@@ -1127,8 +1128,8 @@ vmmoscombine(PilSetOfFrames *sof)
       deleteExtractionTable(extTable);
       for (j = 0; j < mosCount; j++)
         deleteImage(mosList2D[j]);
-      pil_free(mosList2D);
-      pil_free(outSpSkyExStack);
+      cpl_free(mosList2D);
+      cpl_free(outSpSkyExStack);
       return EXIT_FAILURE;
     } 
 
@@ -1140,11 +1141,11 @@ vmmoscombine(PilSetOfFrames *sof)
 
   for (j = 0; j < mosCount; j++)
     deleteImage(mosList2D[j]);
-  pil_free(mosList2D);
+  cpl_free(mosList2D);
 
   for (j = 0; j < mosCount; j++)
     deleteWindowTable(winTablesList[j]);
-  pil_free(winTablesList);
+  cpl_free(winTablesList);
 
 
   /* 
@@ -1163,7 +1164,7 @@ vmmoscombine(PilSetOfFrames *sof)
     deleteImage(outSpSkyExStack[0]);
     deleteImage(outSpSkyExStack[1]);
     deleteExtractionTable(extTable);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     return EXIT_FAILURE;
   }
 
@@ -1186,7 +1187,7 @@ vmmoscombine(PilSetOfFrames *sof)
     deleteWindowTable(combWindowTable);
     deleteImage(outSpSkyExStack[0]);
     deleteImage(outSpSkyExStack[1]);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     return EXIT_FAILURE;
   }
 
@@ -1214,7 +1215,7 @@ vmmoscombine(PilSetOfFrames *sof)
   if (error) {
     deleteImage(outSpSkyExStack[0]);
     deleteImage(outSpSkyExStack[1]);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     deleteObjectTable(objectTable);
     deleteWindowTable(combWindowTable);
     return EXIT_FAILURE;
@@ -1266,9 +1267,9 @@ vmmoscombine(PilSetOfFrames *sof)
   
     if (error) {
       deleteImage(imaSpEx1D[0]);
-      pil_free(imaSpEx1D);
+      cpl_free(imaSpEx1D);
       deleteImage(outSpSkyExStack[0]);
-      pil_free(outSpSkyExStack);
+      cpl_free(outSpSkyExStack);
       deleteObjectTable(objectTable);
       deleteWindowTable(combWindowTable);
       return EXIT_FAILURE;
@@ -1352,9 +1353,9 @@ vmmoscombine(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure updating product 1 header");
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[0]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyExStack[0]);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     deleteObjectTable(objectTable);
     deleteWindowTable(combWindowTable);
     return EXIT_FAILURE;
@@ -1370,7 +1371,7 @@ vmmoscombine(PilSetOfFrames *sof)
   removeDescriptor(&(imaSpEx1D[0]->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
   
-  strlower(strcpy(output1DName, mosReducedCategory));
+  vmstrlower(strcpy(output1DName, mosReducedCategory));
   strcat(output1DName, ".fits");
 
   if (createFitsImage(output1DName, imaSpEx1D[0], mosReducedCategory)) {
@@ -1387,16 +1388,16 @@ vmmoscombine(PilSetOfFrames *sof)
     cpl_msg_error(task, "Cannot create local product file %s!", output1DName);
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[0]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyExStack[0]);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     deleteObjectTable(objectTable);
     deleteWindowTable(combWindowTable);
     return EXIT_FAILURE;
   }
   
   deleteImage(imaSpEx1D[0]);
-  pil_free(imaSpEx1D);
+  cpl_free(imaSpEx1D);
 
   if (calibrateFlux) {
 
@@ -1453,7 +1454,7 @@ vmmoscombine(PilSetOfFrames *sof)
       cpl_msg_error(task, "Failure updating product 1 header");
       deleteImage(imaSpEx1DCal);
       deleteImage(outSpSkyExStack[0]);
-      pil_free(outSpSkyExStack);
+      cpl_free(outSpSkyExStack);
       deleteObjectTable(objectTable);
       deleteWindowTable(combWindowTable);
       return EXIT_FAILURE;
@@ -1468,7 +1469,7 @@ vmmoscombine(PilSetOfFrames *sof)
     removeDescriptor(&(imaSpEx1DCal->descs),
                      pilTrnGetKeyword("TplExposureNumber"));
 
-    strlower(strcpy(output1DName, mosFluxReducedCategory));
+    vmstrlower(strcpy(output1DName, mosFluxReducedCategory));
     strcat(output1DName, ".fits");
 
     if (createFitsImage(output1DName, imaSpEx1DCal, mosFluxReducedCategory)) {
@@ -1485,7 +1486,7 @@ vmmoscombine(PilSetOfFrames *sof)
       cpl_msg_error(task, "Cannot create local product file %s!", output1DName);
       deleteImage(imaSpEx1DCal);
       deleteImage(outSpSkyExStack[0]);
-      pil_free(outSpSkyExStack);
+      cpl_free(outSpSkyExStack);
       deleteObjectTable(objectTable);
       deleteWindowTable(combWindowTable);
       return EXIT_FAILURE;
@@ -1556,7 +1557,7 @@ vmmoscombine(PilSetOfFrames *sof)
   if (!updateOK) {
     cpl_msg_error(task, "Failure updating product 2 header");
     deleteImage(outSpSkyExStack[0]);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     deleteObjectTable(objectTable);
     deleteWindowTable(combWindowTable);
     return EXIT_FAILURE;
@@ -1572,7 +1573,7 @@ vmmoscombine(PilSetOfFrames *sof)
   removeDescriptor(&(outSpSkyExStack[0]->descs),
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output2DName, mosExtractedCategory));
+  vmstrlower(strcpy(output2DName, mosExtractedCategory));
   strcat(output2DName, ".fits");
 
   if (createFitsImage(output2DName, 
@@ -1589,14 +1590,14 @@ vmmoscombine(PilSetOfFrames *sof)
   else {
     cpl_msg_error(task, "Cannot create local product file %s!", output2DName);
     deleteImage(outSpSkyExStack[0]);
-    pil_free(outSpSkyExStack);
+    cpl_free(outSpSkyExStack);
     deleteObjectTable(objectTable);
     deleteWindowTable(combWindowTable);
     return EXIT_FAILURE;
   }
 
   deleteImage(outSpSkyExStack[0]);
-  pil_free(outSpSkyExStack);
+  cpl_free(outSpSkyExStack);
 
 
   writeStringDescriptor(&(objectTable->descs), pilTrnGetKeyword("DoCategory"),
@@ -1604,7 +1605,7 @@ vmmoscombine(PilSetOfFrames *sof)
 
   deleteSetOfDescriptors(&(objectTable->descs), "ESO QC*");
 
-  strlower(strcpy(objectTableName, objectTableCategory));
+  vmstrlower(strcpy(objectTableName, objectTableCategory));
   /* strcat(objectTableName, ".TFITS"); */
   strcat(objectTableName, ".fits");
 
@@ -1647,7 +1648,7 @@ vmmoscombine(PilSetOfFrames *sof)
 
   deleteSetOfDescriptors(&(combWindowTable->descs), "ESO QC*");
 
-  strlower(strcpy(windowTableName, windowTableCategory));
+  vmstrlower(strcpy(windowTableName, windowTableCategory));
   /* strcat(windowTableName, ".TFITS"); */
   strcat(windowTableName, ".fits");
 
