@@ -73,6 +73,7 @@
 /* #include "vmmossphotcalib.h"  */
 #include "vmmosutils.h"
 #include "vmcpl.h"
+#include "vimos_dfs.h"
 
 
 #define MAX_COMMENT_LENGTH (80)
@@ -1289,7 +1290,14 @@ vmmosstandard(PilSetOfFrames *sof)
 
 
   /*
-   *  Bias removal from MOS frame
+   * Now go for the bias subtraction
+   * 
+   * NOTE: This includes the overscan subtraction if biasMethod = BIAS_ZMASTER,
+   * which is the default. Since the overscan region in the master bias has 
+   * been created with growOverscans, there is some extra noise added here,
+   * but this can probably be ignored. A better approach is to use the method
+   * used in the MOS pipeline: subtract overscan for each individual frame,
+   * then subtract bias.
    */
 
   cpl_msg_info(task, "Bias removal...");
@@ -1590,7 +1598,7 @@ vmmosstandard(PilSetOfFrames *sof)
 
   deleteImage(outSpSkyFra[0]);
   deleteImage(outSpSkyFra[1]);
-  pil_free(outSpSkyFra);
+  cpl_free(outSpSkyFra);
 
   if (!outSpEx2D) {
     cpl_msg_error(task, "Failure in 2D extraction of spectra");
@@ -1614,7 +1622,7 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteImage(mosImage);
     deleteImage(outSpEx2D[0]);
     deleteImage(outSpEx2D[1]);
-    pil_free(outSpEx2D);
+    cpl_free(outSpEx2D);
     deleteExtractionTable(extractionTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1644,10 +1652,10 @@ vmmosstandard(PilSetOfFrames *sof)
     cpl_msg_error(task, "Iteration on object detection failed");
     deleteImage(mosImage);
     deleteImage(outSpEx2D[0]);
-    pil_free(outSpEx2D);
+    cpl_free(outSpEx2D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteExtractionTable(extractionTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1656,7 +1664,7 @@ vmmosstandard(PilSetOfFrames *sof)
   deleteWindowTable(dummyWindow);
   deleteExtractionTable(extractionTable);
   deleteImage(outSpEx2D[0]);
-  pil_free(outSpEx2D);
+  cpl_free(outSpEx2D);
 
   if (numObjsInWindowTable(windowTable) < 1) {
     deleteImage(mosImage);
@@ -1664,7 +1672,7 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteWindowTable(windowTable);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     return EXIT_FAILURE;
   }
 
@@ -1676,7 +1684,7 @@ vmmosstandard(PilSetOfFrames *sof)
       deleteWindowTable(windowTable);
       deleteImage(outSpSkyEx[0]);
       deleteImage(outSpSkyEx[1]);
-      pil_free(outSpSkyEx);
+      cpl_free(outSpSkyEx);
       return EXIT_FAILURE;
     }
     else {
@@ -1703,7 +1711,7 @@ vmmosstandard(PilSetOfFrames *sof)
             deleteWindowTable(windowTable);
             deleteImage(outSpSkyEx[0]);
             deleteImage(outSpSkyEx[1]);
-            pil_free(outSpSkyEx);
+            cpl_free(outSpSkyEx);
             return EXIT_FAILURE;
           }
         }
@@ -1745,7 +1753,7 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteImage(mosImage);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1789,10 +1797,10 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteImage(mosImage);
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -1834,10 +1842,10 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteImage(mosImage);
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteTable(atmTable);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
@@ -2001,10 +2009,10 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteImage(mosImage);
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2221,10 +2229,10 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteTable(sphotTable);
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2240,7 +2248,7 @@ vmmosstandard(PilSetOfFrames *sof)
   removeDescriptor(&(imaSpEx1DCal->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output1DName, mosReducedCategory));
+  vmstrlower(strcpy(output1DName, mosReducedCategory));
   strcat(output1DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -2270,10 +2278,10 @@ vmmosstandard(PilSetOfFrames *sof)
     deleteTable(sphotTable);
     deleteImage(imaSpEx1DCal);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2316,10 +2324,10 @@ vmmosstandard(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure updating product header");
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2335,7 +2343,7 @@ vmmosstandard(PilSetOfFrames *sof)
   removeDescriptor(&(outSpSkyEx[0]->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output2DName, mosExtractedCategory));
+  vmstrlower(strcpy(output2DName, mosExtractedCategory));
   strcat(output2DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -2364,10 +2372,10 @@ vmmosstandard(PilSetOfFrames *sof)
     cpl_msg_error(task, "Cannot create local product file %s!", output2DName);
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[0]);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2410,9 +2418,9 @@ vmmosstandard(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure updating product header");
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2427,7 +2435,7 @@ vmmosstandard(PilSetOfFrames *sof)
   removeDescriptor(&(outSpSkyEx[1]->descs), 
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output2DSkyName, mosSkyCategory));
+  vmstrlower(strcpy(output2DSkyName, mosSkyCategory));
   strcat(output2DSkyName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -2457,9 +2465,9 @@ vmmosstandard(PilSetOfFrames *sof)
                   "Cannot create local product file %s!", output2DSkyName);
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteImage(outSpSkyEx[1]);
-    pil_free(outSpSkyEx);
+    cpl_free(outSpSkyEx);
     deleteObjectTable(objectTable);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
@@ -2467,14 +2475,14 @@ vmmosstandard(PilSetOfFrames *sof)
 
   deleteImage(outSpSkyEx[1]);
 
-  pil_free(outSpSkyEx);
+  cpl_free(outSpSkyEx);
 
   writeStringDescriptor(&(objectTable->descs), pilTrnGetKeyword("DoCategory"),
                         objectTableCategory, "Category of pipeline product");
 
   deleteSetOfDescriptors(&(objectTable->descs), "ESO QC*");
 
-  strlower(strcpy(objectTableName, objectTableCategory));
+  vmstrlower(strcpy(objectTableName, objectTableCategory));
   /* strcat(objectTableName, ".TFITS"); */
   strcat(objectTableName, ".fits");
 
@@ -2509,7 +2517,7 @@ vmmosstandard(PilSetOfFrames *sof)
   if (error) {
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     deleteWindowTable(windowTable);
     return EXIT_FAILURE;
   }
@@ -2519,7 +2527,7 @@ vmmosstandard(PilSetOfFrames *sof)
 
   deleteSetOfDescriptors(&(windowTable->descs), "ESO QC*");
 
-  strlower(strcpy(windowTableName, windowTableCategory));
+  vmstrlower(strcpy(windowTableName, windowTableCategory));
   /* strcat(windowTableName, ".TFITS"); */
   strcat(windowTableName, ".fits");
 
@@ -2554,7 +2562,7 @@ vmmosstandard(PilSetOfFrames *sof)
   if (error) {
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     return EXIT_FAILURE;
   }
 
@@ -2591,7 +2599,7 @@ vmmosstandard(PilSetOfFrames *sof)
     cpl_msg_error(task, "Failure updating product header");
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     return EXIT_FAILURE;
   } 
 
@@ -2606,7 +2614,7 @@ vmmosstandard(PilSetOfFrames *sof)
   removeDescriptor(&(imaSpEx1D[1]->descs),
                    pilTrnGetKeyword("TplExposureNumber"));
 
-  strlower(strcpy(output1DName, mosSkyReducedCategory));
+  vmstrlower(strcpy(output1DName, mosSkyReducedCategory));
   strcat(output1DName, ".fits");
 
 /* Align WCS to convention used with IFU */
@@ -2635,14 +2643,14 @@ vmmosstandard(PilSetOfFrames *sof)
     cpl_msg_error(task, "Cannot create local product file %s!", output1DName);
     deleteTable(sphotTable);
     deleteImage(imaSpEx1D[1]);
-    pil_free(imaSpEx1D);
+    cpl_free(imaSpEx1D);
     return EXIT_FAILURE;
   }
 
   deleteImage(imaSpEx1D[1]);
-  pil_free(imaSpEx1D);
+  cpl_free(imaSpEx1D);
 
-  strlower(strcpy(sphotTableName, sphotTableCategory));
+  vmstrlower(strcpy(sphotTableName, sphotTableCategory));
   /* strcat(sphotTableName, ".TFITS"); */
   strcat(sphotTableName, ".fits");
 
