@@ -265,10 +265,9 @@ vmCplFramesetExport(const cpl_frameset *set, PilSetOfFrames *sof)
 
     if (set != NULL || !cpl_frameset_is_empty(set)) {
 
-        const cpl_frame *frame = cpl_frameset_get_first_const(set);
-
-
-        while (frame != NULL) {
+        for (int i =0; i< cpl_frameset_get_size(set); i ++) 
+        {
+            const cpl_frame * frame = cpl_frameset_get_position_const(set, i);
 
             if (cpl_frame_get_group(frame) != CPL_FRAME_GROUP_PRODUCT) {
 
@@ -285,8 +284,6 @@ vmCplFramesetExport(const cpl_frameset *set, PilSetOfFrames *sof)
 
             }
 
-            frame = cpl_frameset_get_next_const(set);
-
         }
 
     }
