@@ -39,6 +39,7 @@
 #include <piltranslator.h>
 
 #include "vmdetector.h"
+#include "cpl.h"
 
 
 #define MAX_COMMENT_LENGTH (80)
@@ -70,7 +71,7 @@ VimosWindow *newWindow(void)
 {
   VimosWindow *window;
 
-  window = (VimosWindow *) pil_malloc(sizeof(VimosWindow));
+  window = (VimosWindow *) cpl_malloc(sizeof(VimosWindow));
   if (window) {
     window->startX = 0;
     window->startY = 0;
@@ -112,7 +113,7 @@ void deleteWindow(VimosWindow *window)
     * Destroy it
     */
 
-    pil_free(window);
+    cpl_free(window);
     window = NULL;
   }
   return;
@@ -167,7 +168,7 @@ VimosPort *newPort(void)
 {
   VimosPort *port;
 
-  port = (VimosPort *) pil_malloc(sizeof(VimosPort));
+  port = (VimosPort *) cpl_malloc(sizeof(VimosPort));
   if (port) {
     port->window        = newWindow();
     port->prScan        = newWindow();
@@ -216,7 +217,7 @@ void deletePort(VimosPort *port)
     deleteWindow(port->ovScan);
     deleteWindow(port->readOutWindow);
 
-    pil_free(port);
+    cpl_free(port);
   }
   return;
 }
@@ -1122,7 +1123,7 @@ VimosFloatArray *estimateImageBias(VimosImage *image, VimosPort *port)
 
       sizePrsc = currentPort->prScan->nX * currentPort->prScan->nY;
       prscBiasLevel = computeAverageFloat(bias, sizePrsc);
-      pil_free(bias);
+      cpl_free(bias);
       success = VM_TRUE;
     }
     else {
@@ -1146,7 +1147,7 @@ VimosFloatArray *estimateImageBias(VimosImage *image, VimosPort *port)
 
       sizeOvsc = currentPort->ovScan->nX * currentPort->ovScan->nY;
       ovscBiasLevel = computeAverageFloat(bias, sizeOvsc);
-      pil_free(bias);
+      cpl_free(bias);
       success = VM_TRUE;
     }
     else {
@@ -1230,7 +1231,7 @@ VimosBool subtractOverscan(float a[], int nx, int ny, VimosPort *port)
              currentPort->prScan->nX,
              currentPort->prScan->nY, bias);
 
-      pil_free(bias);
+      cpl_free(bias);
       success = VM_TRUE;
     }
     else {
@@ -1259,7 +1260,7 @@ VimosBool subtractOverscan(float a[], int nx, int ny, VimosPort *port)
              currentPort->ovScan->nX,
              currentPort->ovScan->nY, bias);
 
-      pil_free(bias);
+      cpl_free(bias);
       success = VM_TRUE;
     }
     else {
@@ -1285,7 +1286,7 @@ VimosBool subtractOverscan(float a[], int nx, int ny, VimosPort *port)
              currentPort->window->nX,
              currentPort->window->nY, portWindow);
 
-      pil_free(portWindow);
+      cpl_free(portWindow);
     }
     else break;
   }
@@ -1359,12 +1360,12 @@ int getChipSize(VimosImage *image, int *chipSizeX, int *chipSizeY)
   int        status = EXIT_FAILURE;
   int        i, nChips;
 
-  dscNameChipX = pil_strdup(pilTrnGetKeyword("CHIP1.NX"));
+  dscNameChipX = cpl_strdup(pilTrnGetKeyword("CHIP1.NX"));
   if (findDescriptor(image->descs, dscNameChipX)) {
-    dscNameChipY = pil_strdup(pilTrnGetKeyword("CHIP1.NY"));
+    dscNameChipY = cpl_strdup(pilTrnGetKeyword("CHIP1.NY"));
   }
   else {
-    pil_free((char *) dscNameChipX);
+    cpl_free((char *) dscNameChipX);
 
    /*
     * With more than one chip around, look for the sequence
@@ -1374,13 +1375,13 @@ int getChipSize(VimosImage *image, int *chipSizeX, int *chipSizeY)
     if (readIntDescriptor(image->descs, pilTrnGetKeyword("NCHIPS"), 
                           &nChips, comment) == VM_TRUE) {
       for (i = 0; i < nChips; i++) {
-        dscNameChipX = pil_strdup(pilTrnGetKeyword("CHIPi.NX", i + 1));
+        dscNameChipX = cpl_strdup(pilTrnGetKeyword("CHIPi.NX", i + 1));
         if (findDescriptor(image->descs, dscNameChipX)) {
-          dscNameChipY = pil_strdup(pilTrnGetKeyword("CHIPi.NY", i + 1));
+          dscNameChipY = cpl_strdup(pilTrnGetKeyword("CHIPi.NY", i + 1));
           break;     /* Related descriptors are found */
         }
         else {
-          pil_free(dscNameChipX);
+          cpl_free(dscNameChipX);
           dscNameChipX = NULL;
         }
       } 
@@ -1399,8 +1400,8 @@ int getChipSize(VimosImage *image, int *chipSizeX, int *chipSizeY)
     }
   }
 
-  pil_free(dscNameChipX);
-  pil_free(dscNameChipY);
+  cpl_free(dscNameChipX);
+  cpl_free(dscNameChipY);
 
   return status;
 
@@ -1476,7 +1477,7 @@ VimosFloatArray *estimateImageRon(VimosImage *image, VimosPort *port)
       prscRon = computeVarianceFloat2D(bias, currentPort->prScan->nX, 
                                        currentPort->prScan->nY);
 
-      pil_free(bias);
+      cpl_free(bias);
       success = VM_TRUE;
     }
     else {
@@ -1502,7 +1503,7 @@ VimosFloatArray *estimateImageRon(VimosImage *image, VimosPort *port)
       ovscRon = computeVarianceFloat2D(bias, currentPort->ovScan->startX, 
                                        currentPort->ovScan->startY);
 
-      pil_free(bias);
+      cpl_free(bias);
       success = VM_TRUE;
     }
     else {
