@@ -42,6 +42,7 @@
 #include "vmadfifutable.h"
 #include "vmdistmodels.h"
 #include "vmextractiontable.h"
+#include "cpl.h"
 
 
 /*
@@ -52,7 +53,7 @@ VimosExtractionSlit *newExtractionSlit()
   VimosExtractionSlit *newSlit;
   
   /* allocate memory */
-  newSlit = (VimosExtractionSlit *) pil_malloc(sizeof(VimosExtractionSlit));
+  newSlit = (VimosExtractionSlit *) cpl_malloc(sizeof(VimosExtractionSlit));
 
   /* check if space was allocated */
   if (newSlit == NULL) {
@@ -127,10 +128,10 @@ void deleteExtractionSlit(VimosExtractionSlit *slit)
         deleteDistModel1D(tmpSlit->crvPol[i]);
         deleteDistModel1D(tmpSlit->invDis[i]);
       }
-      pil_free(tmpSlit->crvPol);
-      pil_free(tmpSlit->invDis);
+      cpl_free(tmpSlit->crvPol);
+      cpl_free(tmpSlit->invDis);
     }
-    pil_free(tmpSlit);
+    cpl_free(tmpSlit);
     
     /* address of next slit */
     tmpSlit = nxtSlit;
@@ -149,7 +150,7 @@ VimosExtractionTable *newExtractionTable()
   VimosExtractionTable *newTab;
   
   /* allocate memory */
-  newTab = (VimosExtractionTable *) pil_malloc(sizeof(VimosExtractionTable));
+  newTab = (VimosExtractionTable *) cpl_malloc(sizeof(VimosExtractionTable));
 
   /* check if space was allocated */
   if (newTab == NULL) {
@@ -163,7 +164,7 @@ VimosExtractionTable *newExtractionTable()
   newTab->descs = newStringDescriptor("ESO PRO TABLE", VM_EXT, "");
   if (newTab->descs == NULL) {
     /* cleanup */
-    pil_free(newTab);
+    cpl_free(newTab);
     cpl_msg_error(modName, "Function newStringDescriptor failure");
     return(NULL);
   }
@@ -845,9 +846,9 @@ VimosBool readFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
   }
 
   /* allocate space for the column labels */
-  ttype = (char **) pil_malloc(nCols*sizeof(char *));
+  ttype = (char **) cpl_malloc(nCols*sizeof(char *));
   for (ii = 0; ii < nCols; ii++) {
-    ttype[ii] = (char *) pil_malloc(FLEN_VALUE*sizeof(char));
+    ttype[ii] = (char *) cpl_malloc(FLEN_VALUE*sizeof(char));
 
     /* check if space was allocated */
     if (ttype[ii] == NULL) {
@@ -931,7 +932,7 @@ VimosBool readFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
     return(VM_FALSE);
   }
 
-  crvPolCol = (int *) pil_malloc((crvOrder+1)*sizeof(int));
+  crvPolCol = (int *) cpl_malloc((crvOrder+1)*sizeof(int));
   /* check if space was allocated */
   if (crvPolCol == NULL) {
     cpl_msg_error(modName, "Allocation Error");
@@ -947,7 +948,7 @@ VimosBool readFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
     }
   }
 
-  invDisCol = (int *) pil_malloc((invOrder+1)*sizeof(int));
+  invDisCol = (int *) cpl_malloc((invOrder+1)*sizeof(int));
   /* check if space was allocated */
   if (invDisCol == NULL) {
     cpl_msg_error(modName, "Allocation Error");
@@ -1078,7 +1079,7 @@ VimosBool readFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
       return(VM_FALSE);
     }   
     exSlit->crvPol = 
-      (VimosDistModel1D **)pil_malloc(slitLen*sizeof(VimosDistModel1D *));
+      (VimosDistModel1D **)cpl_malloc(slitLen*sizeof(VimosDistModel1D *));
     /* check if space was allocated */
     if (exSlit->crvPol == NULL) {
       deleteExtractionSlit(exSlit);
@@ -1092,7 +1093,7 @@ VimosBool readFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
       return(VM_FALSE);
     }   
     exSlit->invDis = 
-      (VimosDistModel1D **)pil_malloc(slitLen*sizeof(VimosDistModel1D *));
+      (VimosDistModel1D **)cpl_malloc(slitLen*sizeof(VimosDistModel1D *));
     if (exSlit->invDis == NULL) {
       deleteExtractionSlit(exSlit);
       cpl_msg_error(modName, "Allocation Error");
@@ -1212,10 +1213,10 @@ VimosBool readFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
     
   }
    
-  pil_free(crvPolCol);
-  pil_free(invDisCol);
+  cpl_free(crvPolCol);
+  cpl_free(invDisCol);
   for (ii = 0; ii < 3; ii++){     /* free the memory for the column labels */
-    pil_free( ttype[ii] );
+    cpl_free( ttype[ii] );
   }
 
   return (VM_TRUE);
@@ -1282,13 +1283,13 @@ VimosBool writeFitsExtractionTable(VimosExtractionTable *extTable, fitsfile
 
   for (i = 0; i <= 15+crvOrder+1+invOrder+1; i++){  
     /* allocate space for the column labels */
-    ttype[i] = (char *) pil_malloc(FLEN_VALUE);  /* max label length = 69 */
+    ttype[i] = (char *) cpl_malloc(FLEN_VALUE);  /* max label length = 69 */
     /* check if space was allocated */
     if (ttype[i] == NULL) {
       cpl_msg_error("writeFitsExtractionTable","Allocation Error");
       return(VM_FALSE);
     }
-    tform[i] = (char *) pil_malloc(FLEN_VALUE);
+    tform[i] = (char *) cpl_malloc(FLEN_VALUE);
     /* check if space was allocated */
     if (tform[i] == NULL) {
       cpl_msg_error("writeFitsExtractionTable","Allocation Error");
