@@ -39,7 +39,6 @@
 #include <fitsio.h>
 #include <fitsio2.h>
 
-#include <pilmemory.h>
 #include <pilmessages.h>
 #include <cpl_msg.h>
 #include <piltranslator.h>
@@ -49,8 +48,8 @@
 #include "vmimage.h"
 
 
-#include <pilmemory.h>
 #include <pilmessages.h>
+#include "cpl.h"
 
 
 /**
@@ -66,7 +65,7 @@ VimosImage *newImage(int xlen, int ylen, float *data)
   const char  modName[] = "newImage";
   VimosImage *tImage;
   
-  tImage = (VimosImage *) pil_malloc(sizeof(VimosImage));
+  tImage = (VimosImage *) cpl_malloc(sizeof(VimosImage));
 
   /* check if space was allocated */
   if (tImage == NULL) {
@@ -98,7 +97,7 @@ VimosImage *newImageAndAlloc(int xlen, int ylen)
     return(NULL);
   }
     
-  tmpImage->data = (float *)pil_calloc(xlen * ylen, sizeof(float));
+  tmpImage->data = (float *)cpl_calloc(xlen * ylen, sizeof(float));
   if (tmpImage->data == NULL) {
     /* cleanup */
     deleteImage(tmpImage);
@@ -115,9 +114,9 @@ void deleteImage(VimosImage *image)
   if (image != NULL) {
     deleteAllDescriptors(image->descs);
     if (image->data != NULL) {
-      pil_free(image->data);
+      cpl_free(image->data);
     }
-    pil_free(image);
+    cpl_free(image);
   }
 }
 
@@ -125,7 +124,7 @@ void deleteImageAndAlloc(VimosImage *image)
 {
   if (image != NULL) {
     if (image->data != NULL) {
-      pil_free(image->data);
+      cpl_free(image->data);
       image->data = NULL;
     }
   }
@@ -443,9 +442,9 @@ VimosBool loadFitsData(VimosImage *image)
 
   npixels  = image->xlen * image->ylen;
 
-  pil_free(image->data);             /* Avoid possible leaks */
+  cpl_free(image->data);             /* Avoid possible leaks */
 
-  image->data = (float *)pil_malloc(npixels * sizeof(float));
+  image->data = (float *)cpl_malloc(npixels * sizeof(float));
 
   if (image->data == NULL) {
     cpl_msg_debug(modName, "Allocation error!");
@@ -839,7 +838,7 @@ VimosImage *VmFrAveFil(VimosImage *ima_in, int filtsizex, int filtsizey,
   f2x = filtsizex/2;
   f2y = filtsizey/2;
   filt_img = newImageAndAlloc(ima_in->xlen, ima_in->ylen);
-  buf = pil_malloc(filtsizex*filtsizey*sizeof(float));
+  buf = cpl_malloc(filtsizex*filtsizey*sizeof(float));
 
   for (row=0; row<ima_in->ylen; row++){
     loleft_y = row - f2y;
@@ -902,7 +901,7 @@ VimosImage *VmFrAveFil(VimosImage *ima_in, int filtsizex, int filtsizey,
       filt_img->data[col+row*filt_img->xlen] = computeAverageFloat(buf,avesize);
     }
   }
-  pil_free(buf);
+  cpl_free(buf);
   return filt_img;
 }
 
@@ -962,7 +961,7 @@ VimosImage *VmFrMedFil(VimosImage *ima_in, int filtsizex, int filtsizey,
   f2x = filtsizex/2;
   f2y = filtsizey/2;
   filt_img = newImageAndAlloc(ima_in->xlen, ima_in->ylen);
-  buf = pil_malloc(filtsizex*filtsizey*sizeof(float));
+  buf = cpl_malloc(filtsizex*filtsizey*sizeof(float));
 
   for (row=0; row<ima_in->ylen; row++){
     loleft_y = row - f2y;
@@ -1025,7 +1024,7 @@ VimosImage *VmFrMedFil(VimosImage *ima_in, int filtsizex, int filtsizey,
       filt_img->data[col+row*filt_img->xlen] = medianPixelvalue(buf,medsize);
     }
   }
-  pil_free(buf);
+  cpl_free(buf);
   return filt_img;
 }
 
@@ -1356,7 +1355,7 @@ VimosImage *frCombAverage32000(VimosImage **ima_list, int num)
 
   ima_ave = newImageAndAlloc(xlen, ylen);
 
-  zvalue = (double *)pil_calloc(num, sizeof(double));
+  zvalue = (double *)cpl_calloc(num, sizeof(double));
 
   for (j = 0; j < ylen; j++) {
     for (i = 0; i < xlen; i++) {
@@ -1375,7 +1374,7 @@ VimosImage *frCombAverage32000(VimosImage **ima_list, int num)
     }
   }
 
-  pil_free(zvalue);
+  cpl_free(zvalue);
 
   return(ima_ave);
 }
@@ -1433,7 +1432,7 @@ VimosImage *frCombMedian(VimosImage **ima_list, int num, int flag)
        corresponding to the position x,y. Compute median value.  
        If flag=1 reject -32000 pixel */   
   
-    zvalue =(float*)pil_calloc(num, sizeof(float));
+    zvalue =(float*)cpl_calloc(num, sizeof(float));
 
     if(flag) {
       for (j=0; j<ylen; j++) {
@@ -1460,7 +1459,7 @@ VimosImage *frCombMedian(VimosImage **ima_list, int num, int flag)
 	}
       }
     }
-    pil_free(zvalue);
+    cpl_free(zvalue);
   }
   return ima_med;
 }
@@ -1541,7 +1540,7 @@ VimosImage *frCombMinMaxReject(VimosImage **ima_list, int minrej,
     /* Find pixel intensity in each frame.
        Sort pixel intensities, reject min/max and average. */
 
-    zvalue = (float *) pil_calloc(num, sizeof(float));
+    zvalue = (float *) cpl_calloc(num, sizeof(float));
 
     for (j = 0; j < ylen; j++) {
       for (i = 0; i < xlen; i++) {
@@ -1558,7 +1557,7 @@ VimosImage *frCombMinMaxReject(VimosImage **ima_list, int minrej,
         ima_out->data[i + j * xlen] = average / (maxn - minn);
       }
     }
-    pil_free(zvalue);
+    cpl_free(zvalue);
   }
   return ima_out;
 }
@@ -1615,7 +1614,7 @@ VimosImage *frCombMinMaxReject32000(VimosImage **ima_list, int minrej,
     /* Find pixel intensity in each frame.
        Sort pixel intensities, reject min/max and average. */
 
-    zvalue = (float *) pil_calloc(num, sizeof(float));
+    zvalue = (float *) cpl_calloc(num, sizeof(float));
 
     for (j = 0; j < ylen; j++) {
       for (i = 0; i < xlen; i++) {
@@ -1651,7 +1650,7 @@ VimosImage *frCombMinMaxReject32000(VimosImage **ima_list, int minrej,
         }
       }
     }
-    pil_free(zvalue);
+    cpl_free(zvalue);
   }
   return ima_out;
 }
@@ -1732,7 +1731,7 @@ VimosImage *OLDfrCombMinMaxReject(VimosImage **ima_list, double minrej,
     /* Find pixel intensity in each frame. 
        Sort pixel intensities, reject min/max and average. */   
     
-    zvalue = (float *) pil_calloc(num, sizeof(float));
+    zvalue = (float *) cpl_calloc(num, sizeof(float));
     
     for (j = 0; j < ylen; j++) {
       for (i = 0; i < xlen; i++) {
@@ -1747,7 +1746,7 @@ VimosImage *OLDfrCombMinMaxReject(VimosImage **ima_list, double minrej,
         ima_out->data[i + j * xlen] = average / (maxn - minn);
       }
     }
-    pil_free(zvalue);
+    cpl_free(zvalue);
   }
   return ima_out;
 }
@@ -1817,7 +1816,7 @@ VimosImage *frCombKSigma(VimosImage **ima_list, double dklow,
     
     ima_out = newImageAndAlloc(xlen, ylen); 
     
-    zvalue = (float*) pil_calloc(num, sizeof(float));
+    zvalue = (float*) cpl_calloc(num, sizeof(float));
     
     for (j=0; j<ylen; j++) {
       for (i=0; i<xlen; i++) {
@@ -1847,7 +1846,7 @@ VimosImage *frCombKSigma(VimosImage **ima_list, double dklow,
         ima_out->data[i+j*xlen] = ave/goodpix;
       }
     }
-    pil_free(zvalue);
+    cpl_free(zvalue);
   }
   return ima_out;
 }
@@ -1896,7 +1895,7 @@ VimosImage *frCombKSigma32000(VimosImage **ima_list, double dklow,
 
     ima_out = newImageAndAlloc(xlen, ylen);
 
-    zvalue = (float *)pil_calloc(num, sizeof(float));
+    zvalue = (float *)cpl_calloc(num, sizeof(float));
 
     for (j = 0; j < ylen; j++) {
       for (i = 0; i < xlen; i++) {
@@ -1940,7 +1939,7 @@ VimosImage *frCombKSigma32000(VimosImage **ima_list, double dklow,
         }
       }
     }
-    pil_free(zvalue);
+    cpl_free(zvalue);
   }
   return ima_out;
 }
@@ -2188,7 +2187,7 @@ VimosDpoint *imageHistogram(VimosImage *ima_in, unsigned int nbins)
   nbpix = ima_in->xlen * ima_in->ylen;
   
   bin_size = (double)(max - min)/(double)nbins;
-  h = (VimosUlong32*)pil_calloc(nbins,sizeof(VimosUlong32));
+  h = (VimosUlong32*)cpl_calloc(nbins,sizeof(VimosUlong32));
  
   for (i=0; i<nbpix; i++) { 
     if (ima_in->data[i] >= max) {
@@ -2204,7 +2203,7 @@ VimosDpoint *imageHistogram(VimosImage *ima_in, unsigned int nbins)
     histogram[i].x = min + (double)i * bin_size;
     histogram[i].y = (double)h[i];
   }
-  pil_free(h);
+  cpl_free(h);
   return histogram;
 }
 
@@ -2353,7 +2352,7 @@ float *collapse2Dto1D(VimosImage *ima_in, int x, int y, int nx,
   
   switch(collapse){
   case ROW:
-    a1d = pil_calloc(nx,sizeof(float)); 
+    a1d = cpl_calloc(nx,sizeof(float)); 
     for (i=0; i<nx; i++) {
       sum = sumPixelsInImage(ima_in,x+i,y,1,ny);
       a1d[i]=sum;
@@ -2361,7 +2360,7 @@ float *collapse2Dto1D(VimosImage *ima_in, int x, int y, int nx,
     break;
     
   case COLUMN:
-    a1d = pil_calloc(ny,sizeof(float)); 
+    a1d = cpl_calloc(ny,sizeof(float)); 
     for (i=0;i<ny; i++) {
       sum = sumPixelsInImage(ima_in,x,y+i,nx,1);
       a1d[i]=sum;
@@ -2537,8 +2536,7 @@ VimosPixel *finePositionSimple(VimosImage *ima_in, VimosPixel *in_pixel,
   int         x_left=0, x_right=0, y_low=0, y_high=0;
   int         xsize, ysize;
   double      est_x, est_y;
-  double      corr_x, corr_y;
-  double      sum_weights;
+  double      corr_y;
   double      inx, iny;
   float       posx, posy;
   float      *sample;
@@ -2581,8 +2579,7 @@ VimosPixel *finePositionSimple(VimosImage *ima_in, VimosPixel *in_pixel,
 /*  Determine the barycenter within the square with dimension r1 centered 
     on the pixel */
 
-  corr_x = corr_y = 0.00;
-  sum_weights = 0.00;
+  corr_y = 0.00;
   x_left  = MAX(floor(est_x)-r1, 0.);
   x_right = MIN(ceil(est_x)+r1, ima_in->xlen);
   y_low   = MAX(floor(est_y)-r1, 0.);
@@ -2604,7 +2601,7 @@ VimosPixel *finePositionSimple(VimosImage *ima_in, VimosPixel *in_pixel,
     return NULL;
   }
      
-  pil_free(sample);
+  cpl_free(sample);
 
   return(corr_pixel);
 }
@@ -2658,7 +2655,7 @@ VimosImage *imageShift(VimosImage *imageIn, float xshift, float yshift, int outX
   /* Setup arrays for the interpolation*/
   inpXlen = imageIn->xlen;
   
-  leaps = (VimosLong32 *) pil_malloc(16*sizeof(VimosLong32));
+  leaps = (VimosLong32 *) cpl_malloc(16*sizeof(VimosLong32));
   
   /* Check if space was allocated */
   if (leaps == NULL) {
@@ -3063,11 +3060,11 @@ char **getFitsFileExtensionsNames(fitsfile *fptr, int *extNum)
   *extNum = 0;
 
   fits_get_num_hdus(fptr, extNum, &status);
-  extNames = (char **) pil_malloc(*extNum*sizeof(char *));
+  extNames = (char **) cpl_malloc(*extNum*sizeof(char *));
 
   if (*extNum > 1) {
     for (i=2; i <= *extNum; i++) {
-      extNames[i-2] = (char *) pil_malloc(FLEN_VALUE*sizeof(char));
+      extNames[i-2] = (char *) cpl_malloc(FLEN_VALUE*sizeof(char));
       fits_movabs_hdu(fptr, i, NULL, &status);
       fits_read_key_str(fptr,"EXTNAME",extNames[i-2],NULL,&status);
       if (status) {
@@ -3256,10 +3253,18 @@ int polySmooth(VimosImage *image, int ord, int hw)
 
 
   if (image->ylen > 1)
+  {
+    free(smoo);
+    free(row);
     return EXIT_FAILURE;
+  }
 
   if (box > image->xlen)
+  {
+    free(smoo);
+    free(row);
     return EXIT_FAILURE;
+  }
 
   /*
    * Copy first hw and last hw items
