@@ -49,6 +49,7 @@
 #include "vmwcsutils.h"
 #include "vmimgextraction.h"
 #include "vmimgastrometry.h"
+#include "cpl.h"
 
 
 /**
@@ -474,7 +475,7 @@ VimosTable *resetAstroTable (int count, char *filterName)
   astroTable->cols->len= totcount;
   currentColumn = astroTable->cols;
   for(i=0; i<totcount; i++) 
-    currentColumn->colValue->sArray[i] = pil_strdup("    ");
+    currentColumn->colValue->sArray[i] = cpl_strdup("    ");
         
   currentColumn->next = newDoubleColumn(totcount, "RA");
   currentColumn = currentColumn->next;
@@ -812,7 +813,7 @@ VimosBool fitCO(VimosImage *image, VimosTable *astroTable,
   
   if ((vimosFitPlate(wcs, starMatch, astroTable, nmatch, vmncoef, &chisq) == 
       VM_FALSE)) { 
-    pil_free(imatch);
+    cpl_free(imatch);
     return VM_FALSE;
   }
    
@@ -841,7 +842,7 @@ VimosBool fitCO(VimosImage *image, VimosTable *astroTable,
   if(!imatch || nmatch < minstar) {
     cpl_msg_warning(modName, "Insufficent number of matching stars: %d found",
                   nmatch);
-    pil_free(imatch);
+    cpl_free(imatch);
     return VM_FALSE;
   }      
     
