@@ -54,6 +54,7 @@
 #include "vmsextractor.h"
 #include "vmimgutils.h"
 #include "vmimgextraction.h"
+#include "cpl.h"
 
 
 #define SEXTRACTOR_ARGC  20
@@ -329,7 +330,7 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
     /* FIXME: Is the extra element really needed?
      */
 
-    if ((buffer = pil_calloc(sz + 1, sizeof(float))) == 0)
+    if ((buffer = cpl_calloc(sz + 1, sizeof(float))) == 0)
       return 0;
 
     switch (column->colType) {
@@ -355,7 +356,7 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
       default:
         cpl_msg_debug(fctid, "Type of column '%s' is not supported!",
                     name);
-        pil_free(buffer);
+        cpl_free(buffer);
         return 0;
     }
 
@@ -364,11 +365,11 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
      * Allocate working buffers
      */
 
-    if ((indexTable = pil_calloc(sz, sizeof(int))) == 0)
+    if ((indexTable = cpl_calloc(sz, sizeof(int))) == 0)
       return 0;
 
     Indexx(sz, buffer, indexTable);
-    pil_free(buffer);
+    cpl_free(buffer);
 
 
     /*
@@ -381,9 +382,9 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
      */
 
     bucket.size = sz * sizeof(double);
-    bucket.data = (unsigned char *)pil_calloc(bucket.size, sizeof(unsigned char));
+    bucket.data = (unsigned char *)cpl_calloc(bucket.size, sizeof(unsigned char));
     if (!bucket.data) {
-      pil_free(indexTable);
+      cpl_free(indexTable);
       return 0;
     }
 
@@ -397,9 +398,9 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
         int *handle, *columnData;
 
         if ((bytes = sz * sizeof(int)) > bucket.size) {
-          if (!pil_realloc(bucket.data, bytes)) {
-            pil_free(bucket.data);
-            pil_free(indexTable);
+          if (!cpl_realloc(bucket.data, bytes)) {
+            cpl_free(bucket.data);
+            cpl_free(indexTable);
             return 0;
           }
           else
@@ -422,9 +423,9 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
         float *handle, *columnData;
 
         if ((bytes = sz * sizeof(float)) > bucket.size) {
-          if (!pil_realloc(bucket.data, bytes)) {
-            pil_free(bucket.data);
-            pil_free(indexTable);
+          if (!cpl_realloc(bucket.data, bytes)) {
+            cpl_free(bucket.data);
+            cpl_free(indexTable);
             return 0;
           }
           else
@@ -445,9 +446,9 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
         double *handle, *columnData;
 
         if ((bytes = sz * sizeof(double)) > bucket.size) {
-          if (!pil_realloc(bucket.data, bytes)) {
-            pil_free(bucket.data);
-            pil_free(indexTable);
+          if (!cpl_realloc(bucket.data, bytes)) {
+            cpl_free(bucket.data);
+            cpl_free(indexTable);
             return 0;
           }
           else
@@ -469,9 +470,9 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
         char **handle, **columnData;
 
         if ((bytes = sz * sizeof(char *)) > bucket.size) {
-          if (!pil_realloc(bucket.data, bytes)) {
-            pil_free(bucket.data);
-            pil_free(indexTable);
+          if (!cpl_realloc(bucket.data, bytes)) {
+            cpl_free(bucket.data);
+            cpl_free(indexTable);
             return 0;
           }
           else
@@ -490,8 +491,8 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
 
       default:
         cpl_msg_debug(fctid, "Invalid column type!");
-        pil_free(bucket.data);
-        pil_free(indexTable);
+        cpl_free(bucket.data);
+        cpl_free(indexTable);
         return 0;
         break;
       }
@@ -500,8 +501,8 @@ inline static VimosTable *sortTable(VimosTable *table, const char *name)
 
     }
 
-    pil_free(bucket.data);
-    pil_free(indexTable);
+    cpl_free(bucket.data);
+    cpl_free(indexTable);
 
   }
 
@@ -977,7 +978,7 @@ VimosTable *VmImBuildStarTable(VimosTable *table, float starIndex,
    */
 
   objectCount = colGetSize(columns[0]);
-  selectedEntry = (int *)pil_calloc(objectCount, sizeof(int));
+  selectedEntry = (int *)cpl_calloc(objectCount, sizeof(int));
 
   /*
    * Check the selection criteria and count the stars.
@@ -1006,7 +1007,7 @@ VimosTable *VmImBuildStarTable(VimosTable *table, float starIndex,
   if (starCount <= 0) {
     cpl_msg_warning(fctid, "No stars found for current settings!");
     starTable = newStarTableEmpty();
-    pil_free(selectedEntry);
+    cpl_free(selectedEntry);
     return 0;
   }
   else {
@@ -1021,11 +1022,11 @@ VimosTable *VmImBuildStarTable(VimosTable *table, float starIndex,
 
   if (!starTable) {
     cpl_msg_error(fctid, "Cannot create star table!");
-    pil_free(selectedEntry);
+    cpl_free(selectedEntry);
     return 0;
   }
   else {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       vimosDscCopy(&(starTable->descs), table->descs,
                    ".*-OBS$", hint);
@@ -1036,7 +1037,7 @@ VimosTable *VmImBuildStarTable(VimosTable *table, float starIndex,
       vimosDscCopy(&(starTable->descs), table->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
   }
           
 
@@ -1068,7 +1069,7 @@ VimosTable *VmImBuildStarTable(VimosTable *table, float starIndex,
      
   }
 
-  pil_free(selectedEntry);
+  cpl_free(selectedEntry);
 
   return starTable;
 }
@@ -1236,7 +1237,7 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
                                  minStars, &matchCount);
 
     if (!indexTable) {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       cpl_msg_warning(fctid, "Search for matching stars failed!");
 
@@ -1251,7 +1252,7 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
 
       return stmcTable;
     }
@@ -1274,12 +1275,12 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
      */
 
     if (!(stmcTable = newStarMatchTable(matchCount))) {
-      pil_free(indexTable);
+      cpl_free(indexTable);
       return 0;
     }
   }
   else {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       stmcTable = newStarMatchTableEmpty();
 
@@ -1292,7 +1293,7 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
 
       return stmcTable;
   }
@@ -1306,13 +1307,13 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
   if (writeWcsInfo(&stmcTable->descs, wcs) == EXIT_FAILURE) {
     cpl_msg_debug(fctid, "Appending WCS keywords failed!");
     
-    pil_free(indexTable);
+    cpl_free(indexTable);
     deleteTable(stmcTable);
 
     return 0;
   }
   else {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    ".*-OBS$", hint);
@@ -1323,7 +1324,7 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
   }
 
   /*
@@ -1423,7 +1424,7 @@ VimosTable *VmImBuildStarMatchTable(VimosImage *image, VimosTable *starTable,
    * Cleanup
    */
 
-  pil_free(indexTable);
+  cpl_free(indexTable);
 
   return stmcTable;
 
@@ -1557,7 +1558,7 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
                                  minStars, &matchCount);
 
     if (!indexTable) {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       cpl_msg_warning(fctid, "Search for matching stars failed!");
 
@@ -1572,7 +1573,7 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
 
       return stmcTable;
     }
@@ -1595,12 +1596,12 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
      */
 
     if (!(stmcTable = newStarMatchTable(matchCount))) {
-      pil_free(indexTable);
+      cpl_free(indexTable);
       return 0;
     }
   }
   else {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       stmcTable = newStarMatchTableEmpty();
 
@@ -1613,7 +1614,7 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
 
       return stmcTable;
   }
@@ -1627,13 +1628,13 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
   if (writeWcsInfo(&stmcTable->descs, wcs) == EXIT_FAILURE) {
     cpl_msg_debug(fctid, "Appending WCS keywords failed!");
     
-    pil_free(indexTable);
+    cpl_free(indexTable);
     deleteTable(stmcTable);
 
     return 0;
   }
   else {
-      char *hint = pil_strdup(pilTrnGetKeyword("Table"));
+      char *hint = cpl_strdup(pilTrnGetKeyword("Table"));
 
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    ".*-OBS$", hint);
@@ -1644,7 +1645,7 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
       vimosDscCopy(&stmcTable->descs, starTable->descs,
                    "^ESO PRO (MAG ZERO|AIRMASS)", hint);
 
-      pil_free(hint);
+      cpl_free(hint);
   }
 
   /*
@@ -1750,7 +1751,7 @@ VimosTable *VmImBuildStarMatchTable_skyccd(VimosImage *image, VimosTable *starTa
    * Cleanup
    */
 
-  pil_free(indexTable);
+  cpl_free(indexTable);
 
   return stmcTable;
 
@@ -1828,7 +1829,7 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
     if (!(configFile = fopen(configName, "w"))) {
       cpl_msg_error(fctid, "Cannot create temporary setup file!");
       
-      pil_free(configName);
+      cpl_free(configName);
 
       return 0;
     }
@@ -1840,7 +1841,7 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
     fclose(configFile);
     remove(configName);
 
-    pil_free(configName);
+    cpl_free(configName);
 
     return 0;
   }
@@ -1859,7 +1860,7 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
 
     remove(configName);
 
-    pil_free(configName);
+    cpl_free(configName);
 
     return 0;
   }
@@ -1869,8 +1870,8 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
       
       remove(configName);
 
-      pil_free(configName);
-      pil_free(parameterName);
+      cpl_free(configName);
+      cpl_free(parameterName);
 
       return 0;
     }
@@ -1885,8 +1886,8 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
     remove(configName);
     remove(parameterName);
 
-    pil_free(configName);
-    pil_free(parameterName);
+    cpl_free(configName);
+    cpl_free(parameterName);
 
     return 0;
   }
@@ -1899,15 +1900,15 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
    * mask setup files. Their existance and permissions are checked.
    */
 
-  if (!(networkName = pil_strdup(sextGetStarNnwName()))) {
+  if (!(networkName = cpl_strdup(sextGetStarNnwName()))) {
     cpl_msg_error(fctid, "Cannot retrieve SExtractor neuronal network "
                 "setup file!");
 
     remove(configName);
     remove(parameterName);
 
-    pil_free(configName);
-    pil_free(parameterName);
+    cpl_free(configName);
+    cpl_free(parameterName);
 
     return 0;
   }
@@ -1919,23 +1920,23 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
       remove(configName);
       remove(parameterName);
 
-      pil_free(configName);
-      pil_free(parameterName);
-      pil_free(networkName);
+      cpl_free(configName);
+      cpl_free(parameterName);
+      cpl_free(networkName);
 
       return 0;
     }
 
 
-  if (!(filterName = pil_strdup(sextGetFilterName()))) {
+  if (!(filterName = cpl_strdup(sextGetFilterName()))) {
     cpl_msg_error(fctid, "Cannot retrieve SExtractor filter setup file!");
 
     remove(configName);
     remove(parameterName);
 
-    pil_free(configName);
-    pil_free(parameterName);
-    pil_free(networkName);
+    cpl_free(configName);
+    cpl_free(parameterName);
+    cpl_free(networkName);
 
     return 0;
   }
@@ -1947,10 +1948,10 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
       remove(configName);
       remove(parameterName);
 
-      pil_free(configName);
-      pil_free(parameterName);
-      pil_free(networkName);
-      pil_free(filterName);
+      cpl_free(configName);
+      cpl_free(parameterName);
+      cpl_free(networkName);
+      cpl_free(filterName);
 
       return 0;
     }
@@ -1974,10 +1975,10 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
     remove(configName);
     remove(parameterName);
 
-    pil_free(configName);
-    pil_free(parameterName);
-    pil_free(networkName);
-    pil_free(filterName);
+    cpl_free(configName);
+    cpl_free(parameterName);
+    cpl_free(networkName);
+    cpl_free(filterName);
 
     return 0;
   }
@@ -2002,11 +2003,11 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
     remove(configName);
     remove(parameterName);
 
-    pil_free(configName);
-    pil_free(parameterName);
-    pil_free(networkName);
-    pil_free(filterName);
-    pil_free(catalogName);
+    cpl_free(configName);
+    cpl_free(parameterName);
+    cpl_free(networkName);
+    cpl_free(filterName);
+    cpl_free(catalogName);
 
     return 0;
   }
@@ -2018,12 +2019,12 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
       remove(configName);
       remove(parameterName);
 
-      pil_free(configName);
-      pil_free(parameterName);
-      pil_free(networkName);
-      pil_free(filterName);
-      pil_free(imageName);
-      pil_free(catalogName);
+      cpl_free(configName);
+      cpl_free(parameterName);
+      cpl_free(networkName);
+      cpl_free(filterName);
+      cpl_free(imageName);
+      cpl_free(catalogName);
 
       return 0;
     }
@@ -2034,7 +2035,7 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
    * Build the SExtractor command line and execute it.
    */
 
-  argv[0] = pil_strdup(sextGetSextractorPath());
+  argv[0] = cpl_strdup(sextGetSextractorPath());
   argv[1] = imageName;
   argv[2] = "-c";
   argv[3] = configName;
@@ -2091,12 +2092,12 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
     remove(parameterName);
     remove(imageName);
 
-    pil_free(configName);
-    pil_free(parameterName);
-    pil_free(networkName);
-    pil_free(filterName);
-    pil_free(imageName);
-    pil_free(catalogName);
+    cpl_free(configName);
+    cpl_free(parameterName);
+    cpl_free(networkName);
+    cpl_free(filterName);
+    cpl_free(imageName);
+    cpl_free(catalogName);
 
     return 0;
   }
@@ -2105,11 +2106,11 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
   remove(parameterName);
   remove(imageName);
 
-  pil_free(configName);
-  pil_free(parameterName);
-  pil_free(networkName);
-  pil_free(filterName);
-  pil_free(imageName);
+  cpl_free(configName);
+  cpl_free(parameterName);
+  cpl_free(networkName);
+  cpl_free(filterName);
+  cpl_free(imageName);
 
 
   /*
@@ -2122,13 +2123,13 @@ VimosTable *VmImDetectObjects(VimosImage *image, VimosImage *badpixels)
 
     remove(catalogName);
 
-    pil_free(catalogName);
+    cpl_free(catalogName);
 
     return 0;
   }
   else {
     remove(catalogName);
-    pil_free(catalogName);
+    cpl_free(catalogName);
   }
 
   if (!(galTable = VmImBuildGalaxyTable(galTable, image))) {
@@ -2301,16 +2302,16 @@ int *VmSearchMatches(VimosTable *sourceList, VimosTable *catalog,
 
   sz = n_ele1 < n_ele2 ? n_ele1 : n_ele2;
 
-  imatch0 = (int *)pil_calloc((size_t)(2 * sz), sizeof(int));
+  imatch0 = (int *)cpl_calloc((size_t)(2 * sz), sizeof(int));
   if (!imatch0) {
     cpl_msg_error(fctid, "Not enough memory!");
     return NULL;
   }
 
   
-  if ((flag = (int *)pil_calloc((size_t)n_ele2, sizeof(int))) == 0) {
+  if ((flag = (int *)cpl_calloc((size_t)n_ele2, sizeof(int))) == 0) {
     cpl_msg_error(fctid, "Not enough memory!");
-    pil_free(imatch0);
+    cpl_free(imatch0);
 
     return NULL;
   }
@@ -2386,11 +2387,11 @@ int *VmSearchMatches(VimosTable *sourceList, VimosTable *catalog,
     }
   }
 
-  pil_free(flag);
+  cpl_free(flag);
 
   if (nmatch0 < (minStars < 2 ? minStars : 2)) {
     cpl_msg_error(fctid, "Insufficient number of matches found [%d]", nmatch0);
-    pil_free(imatch0);
+    cpl_free(imatch0);
 
     return NULL;
   }
@@ -2446,9 +2447,9 @@ int *VmSearchMatches(VimosTable *sourceList, VimosTable *catalog,
      * Find best matches applying a Sigma clipping
      */
     
-    if (!(imatch = (int *)pil_calloc((size_t)(2 * nmatch0), sizeof(int)))) {
+    if (!(imatch = (int *)cpl_calloc((size_t)(2 * nmatch0), sizeof(int)))) {
       cpl_msg_error(fctid, "Not enough memory!");
-      pil_free(imatch0);
+      cpl_free(imatch0);
       return NULL;
     }
 
@@ -2488,13 +2489,13 @@ int *VmSearchMatches(VimosTable *sourceList, VimosTable *catalog,
     if(nrej > 0)
       cpl_msg_debug(fctid, "Rejected %d pair(s)", nrej);
 
-    pil_free (imatch0);
+    cpl_free (imatch0);
     *matches = nmatch;
   }
   else {
-    if (!(imatch = (int *)pil_calloc((size_t)(2 * nmatch0), sizeof(int)))) {
+    if (!(imatch = (int *)cpl_calloc((size_t)(2 * nmatch0), sizeof(int)))) {
       cpl_msg_error(fctid, "Not enough memory!");
-      pil_free(imatch0);
+      cpl_free(imatch0);
 
       return NULL;
     }
