@@ -48,6 +48,7 @@
 #include "vmimage.h"
 #include "vmtable.h"
 #include "vmqcutils.h"
+#include "cpl.h"
 
 
 #define COMMENT_LENGTH    (80)
@@ -71,7 +72,7 @@ static int myqfits_is_int(const char * s)
     if (s[0]==0) return 0 ;
     if (regcomp(&re_int, &regex_int[0], REG_EXTENDED|REG_NOSUB)!=0) {
         printf("internal error: compiling int rule");
-        exit(-1);
+        abort();
     }
     status = regexec(&re_int, s, 0, NULL, 0) ;
     regfree(&re_int) ;
@@ -87,7 +88,7 @@ static int myqfits_is_float(const char * s)
     if (s[0]==0) return 0 ;
     if (regcomp(&re_float, &regex_float[0], REG_EXTENDED|REG_NOSUB)!=0) {
         printf("internal error: compiling float rule");
-        exit(-1);
+        abort();
     }
     status = regexec(&re_float, s, 0, NULL, 0) ;
     regfree(&re_float) ;
@@ -112,7 +113,7 @@ static int myqfits_is_complex(const char * s)
     if (s[0]==0) return 0 ;
     if (regcomp(&re_cmp, &regex_cmp[0], REG_EXTENDED|REG_NOSUB)!=0) {
         printf("internal error: compiling complex rule");
-        exit(-1);
+        abort();
     }
     status = regexec(&re_cmp, s, 0, NULL, 0) ;
     regfree(&re_cmp) ;
@@ -437,22 +438,22 @@ qcSelectConsistentImages(VimosImage **imageList, float *imageNoise,
    * the selection criteria.
    */
 
-  acceptedList = (VimosImage **)pil_calloc(imageCount, sizeof(VimosImage *));
-  rejectedList = (VimosImage **)pil_calloc(imageCount, sizeof(VimosImage *));
-  finalList = (VimosImage **)pil_calloc(imageCount, sizeof(VimosImage *));
+  acceptedList = (VimosImage **)cpl_calloc(imageCount, sizeof(VimosImage *));
+  rejectedList = (VimosImage **)cpl_calloc(imageCount, sizeof(VimosImage *));
+  finalList = (VimosImage **)cpl_calloc(imageCount, sizeof(VimosImage *));
 
   if (!acceptedList || !rejectedList || !finalList) {
     deleteMatrix(offset);
     deleteMatrix(threshold);
 
     if (acceptedList)
-      pil_free(acceptedList);
+      cpl_free(acceptedList);
 
     if (rejectedList)
-      pil_free(rejectedList);
+      cpl_free(rejectedList);
 
     if (finalList)
-      pil_free(finalList);
+      cpl_free(finalList);
     
     pilErrno = P_EGENERIC;
     return 0;
@@ -498,9 +499,9 @@ qcSelectConsistentImages(VimosImage **imageList, float *imageNoise,
    * Cleanup
    */
 
-  pil_free(acceptedList);
-  pil_free(rejectedList);
-  pil_free(finalList);
+  cpl_free(acceptedList);
+  cpl_free(rejectedList);
+  cpl_free(finalList);
 
   return finalCount;
 
@@ -710,7 +711,7 @@ qcCheckDarkLevel(VimosImage *dark, VimosTable *ccdTable, double maxDev,
 
   const char fctid[] = "qcCheckDarkLevel";
 
-  char      *keyname = pil_strdup(pilTrnGetKeyword("DarkLevel"));
+  char      *keyname = cpl_strdup(pilTrnGetKeyword("DarkLevel"));
   char       comment[COMMENT_LENGTH];
 
   double     median, nominal, offset, sigma;
@@ -753,7 +754,7 @@ qcCheckDarkLevel(VimosImage *dark, VimosTable *ccdTable, double maxDev,
                 keyname);
 
     pilErrno = P_EGENERIC;
-    pil_free(keyname);
+    cpl_free(keyname);
 
     return EXIT_FAILURE;
   }
@@ -775,7 +776,7 @@ qcCheckDarkLevel(VimosImage *dark, VimosTable *ccdTable, double maxDev,
                   "tolerance value of %.2f sigma (%.4f)!", maxDev, sigma);
 
       pilErrno = P_ENOERR;
-      pil_free(keyname);
+      cpl_free(keyname);
 
       return EXIT_FAILURE;
     }
@@ -798,7 +799,7 @@ qcCheckDarkLevel(VimosImage *dark, VimosTable *ccdTable, double maxDev,
    * Cleanup
    */
 
-  pil_free(keyname);
+  cpl_free(keyname);
 
   return EXIT_SUCCESS;
 
@@ -873,7 +874,7 @@ qcCopyValue(VimosDescriptor *header, const char *name, const char *unit,
     dvalue = desc->descValue->d;
     break;
   case VM_STRING :
-    svalue = pil_strdup(desc->descValue->s);
+    svalue = cpl_strdup(desc->descValue->s);
     if (!svalue) {
       cpl_msg_error(fctid, "Memory failure!");
       return status;
@@ -888,10 +889,10 @@ qcCopyValue(VimosDescriptor *header, const char *name, const char *unit,
    *  Construct entry name for PAF
    */
 
-  keep = pafName = pil_strdup(name);
+  keep = pafName = cpl_strdup(name);
   if (!pafName) {
     if (svalue)
-      pil_free(svalue);
+      cpl_free(svalue);
     cpl_msg_error(fctid, "Memory failure!");
     return status;
   }
@@ -926,8 +927,8 @@ qcCopyValue(VimosDescriptor *header, const char *name, const char *unit,
     cpl_msg_error(fctid, "Could not copy descriptor value to QC1 PAF!");
 
   if (svalue)
-    pil_free(svalue);
-  pil_free(keep);
+    cpl_free(svalue);
+  cpl_free(keep);
 
   return status;
 
@@ -979,7 +980,7 @@ qcWriteValueInt(VimosDescriptor *header, int value, const char *name,
     return EXIT_FAILURE;
   }
 
-  descName = pil_malloc((strlen(name) + 5) * sizeof(char *));
+  descName = cpl_malloc((strlen(name) + 5) * sizeof(char *));
 
   if (!descName) {
     cpl_msg_error(fctid, "Memory failure!");
@@ -995,7 +996,7 @@ qcWriteValueInt(VimosDescriptor *header, int value, const char *name,
 
   status = writeIntDescriptor(&header, descName, value, comment);
 
-  pil_free(descName);
+  cpl_free(descName);
 
   if (status == VM_FALSE) {
     cpl_msg_error(fctid, "Could not copy value to descriptor header!");
@@ -1052,7 +1053,7 @@ qcWriteValueDouble(VimosDescriptor *header, double value, const char *name,
     return EXIT_FAILURE;
   }
 
-  descName = pil_malloc((strlen(name) + 5) * sizeof(char *));
+  descName = cpl_malloc((strlen(name) + 5) * sizeof(char *));
 
   if (!descName) {
     cpl_msg_error(fctid, "Memory failure!");
@@ -1068,7 +1069,7 @@ qcWriteValueDouble(VimosDescriptor *header, double value, const char *name,
 
   status = writeDoubleDescriptor(&header, descName, value, comment);
 
-  pil_free(descName);
+  cpl_free(descName);
 
   if (status == VM_FALSE) {
     cpl_msg_error(fctid, "Could not copy value to descriptor header!");
@@ -1130,7 +1131,7 @@ qcWriteValueInt_CPL(char *filnam, int value, const char *name,
     return EXIT_FAILURE;
   }
 
-  descName = pil_malloc((strlen(name) + 15) * sizeof(char *));
+  descName = cpl_malloc((strlen(name) + 15) * sizeof(char *));
 
   if (!descName) {
     cpl_msg_error(fctid, "Memory failure!");
@@ -1154,7 +1155,7 @@ qcWriteValueInt_CPL(char *filnam, int value, const char *name,
   qfits_replace_card(filnam, descName, line);
 */
 
-  pil_free(descName);
+  cpl_free(descName);
 
   if (status)
     return EXIT_FAILURE;
@@ -1214,7 +1215,7 @@ qcWriteValueDouble_CPL(char *filnam, double value, const char *name,
     return EXIT_FAILURE;
   }
 
-  descName = pil_malloc((strlen(name) + 15) * sizeof(char *));
+  descName = cpl_malloc((strlen(name) + 15) * sizeof(char *));
 
   if (!descName) {
     cpl_msg_error(fctid, "Memory failure!");
@@ -1238,7 +1239,7 @@ qcWriteValueDouble_CPL(char *filnam, double value, const char *name,
   qfits_replace_card(filnam, descName, line);
 */
 
-  pil_free(descName);
+  cpl_free(descName);
 
   if (status)
     return EXIT_FAILURE;
