@@ -45,6 +45,7 @@
 #include "vmtable.h"
 #include "vmimgutils.h"
 #include "vmsextractor.h"
+#include "cpl.h"
 
 
 #define SEXTRACTOR_GROUP          "SExtractor"
@@ -96,15 +97,15 @@ sextGetFileName(char *buffer, const char *path, size_t n)
 
   memset(buffer, 0, n + 1);
 
-  s = pil_strdup(pilFileExpandFilePath(path));
+  s = cpl_strdup(pilFileExpandFilePath(path));
 
   if (strlen(s) > n) {
-    pil_free(s);
+    cpl_free(s);
     return 0;
   }
 
   strncpy(buffer, s, n);
-  pil_free(s);
+  cpl_free(s);
 
   return buffer;
   
